USE realsecuredb
go
IF OBJECT_ID('iss_Failover_Import_Asset') IS NOT NULL DROP PROCEDURE dbo.iss_Failover_Import_Asset
go
CREATE PROCEDURE dbo.iss_Failover_Import_Asset
AS
/* IBM Confidential - OCO Source Materials */
/* Copyright (c) IBM Corp. 2009 */
/* The source code for this program is not published or otherwise divested of its trade secrets, */
/* irrespective of what has been deposited with the U.S. Copyright Office. */ 

-- This procedure is based off of the asset identification algorithm iss_NetworkInterface_Identify.  It's job is to 
-- identify assets in the destination site (core assets) that exist in the source site and renumber them. Afterwards the entire
-- table can be merged like any other table for major performance gains.
DECLARE @SaveRowCnt int, @ProcName sysname, @SaveErrNbr int
SELECT @ProcName = OBJECT_NAME(@@ProcID)
SET NOCOUNT ON

DECLARE @GUID varchar(36),
	@HostName nvarchar(16),
	@Domain nvarchar(26),
	@DNSName nvarchar(254), 
	@IPV4Nbr numeric(10),
	@IPV4Address varchar(47),
	@HostNameResolved tinyint,
	@OSName nvarchar(64),
	@MACAddress varchar(17),
	@IPv6High	bigint,
	@IPv6Low	bigint,
	@AssetID int,
	@NetworkInterfaceID int,
	@DNSID int	

DECLARE @OSInfoProvided TINYINT,
	@Old_AssetID INT,
	@MatchType VARCHAR(10),
	@FO_NetworkInterfaceID int

DECLARE c CURSOR LOCAL FOR
SELECT NetworkInterfaceID, GUID, HostName, Domain, DNSName, IPV4Nbr, IPV4Address, HostNameResolved, OSName, MACAddress, IPv6High, IPv6Low
FROM NetworkInterface WITH (NOLOCK)
LEFT OUTER JOIN Asset WITH (NOLOCK) ON NetworkInterface.AssetID = Asset.AssetID
LEFT OUTER JOIN DNS WITH (NOLOCK) ON NetworkInterface.DNSID = DNS.DNSID
ORDER BY NetworkInterface.LastModifiedAt

OPEN c

FETCH NEXT FROM c
INTO @FO_NetworkInterfaceID, @GUID, @HostName, @Domain, @DNSName, @IPV4Nbr, @IPV4Address, @HostNameResolved, @OSName, @MACAddress, @IPv6High, @IPv6Low

WHILE @@FETCH_STATUS = 0
	BEGIN
	-- Search for asset first by GUID.  
	IF @GUID IS NOT NULL
		BEGIN
		SELECT TOP 1 @AssetID = AssetID
		FROM Asset_Recovery (UPDLOCK)
		WHERE GUID = @GUID
		ORDER BY LastModifiedAt DESC
		
		IF @@ERROR <> 0 RETURN(1)	
		END

	--Next, search for HostName and Domain
	IF @AssetID IS NULL AND @HostName IS NOT NULL 
		BEGIN
		SELECT TOP 1 @AssetID = AssetID
		FROM Asset_Recovery (UPDLOCK)
		WHERE HostName = @HostName
		AND (@Domain IS NULL OR Domain IS NULL OR Domain = @Domain)
		ORDER BY LastModifiedAt DESC
		
		IF @@ERROR <> 0 RETURN(1)	
		END


	--Find network interface by MAC
	IF @MACAddress IS NOT NULL 
		BEGIN
		--First, search networkinterface records associated with asset
		IF @AssetID IS NOT NULL 
			BEGIN
			SELECT TOP 1 @NetworkInterfaceID = i.NetworkInterfaceID
			FROM NetworkInterface_Recovery i (UPDLOCK)
			WHERE i.MACAddress = @MACAddress
				AND i.AssetID = @AssetID
			ORDER BY i.LastModifiedAt DESC

			IF @@ERROR <> 0 RETURN(1)	
			END

		--Next, search all NetworkInterface records
		IF @NetworkInterfaceID IS NULL 
			BEGIN
			SELECT TOP 1 @NetworkInterfaceID = i.NetworkInterfaceID,
				@Old_AssetID = AssetID
			FROM NetworkInterface_Recovery i (UPDLOCK)
			WHERE i.MACAddress = @MACAddress
			--choose unassigned asset records then unassigned mac records 
			--then most recently updated
			ORDER BY CASE WHEN i.AssetID IS NULL THEN NULL ELSE 'X' END ASC,
				CASE WHEN MACAddress IS NULL THEN NULL ELSE 'X' END ASC, 
				LastModifiedAt DESC 	

			IF @@ERROR <> 0 RETURN(1)	
			END
		IF @NetworkInterfaceID IS NOT NULL
			SELECT @MatchType = 'MAC'
		END

	--Find network interface by unqualified DNS and IP
	IF @NetworkInterfaceID IS NULL AND @DNSName IS NOT NULL AND @IPV4Nbr IS NOT NULL
		BEGIN
		--First, search networkinterface records associated with asset
		IF @AssetID IS NOT NULL 
			BEGIN
			SELECT TOP 1 @NetworkInterfaceID = i.NetworkInterfaceID
			FROM NetworkInterface_Recovery i (UPDLOCK)
			INNER JOIN DNS_Recovery d ON i.DNSID = d.DNSID 
			WHERE  LEFT(d.DNSName+'.',CHARINDEX('.',d.DNSName+'.')-1) = LEFT(@DNSName+'.',CHARINDEX('.',@DNSName+'.')-1)
				AND (i.IPV4Nbr = @IPV4Nbr OR (i.IPv6High = @IPv6High AND i.IPv6Low = @IPv6Low))
				AND i.AssetID = @AssetID
				AND (i.MACAddress IS NULL OR @MACAddress IS NULL)
			ORDER BY 
				CASE
					WHEN i.IPv6High = @IPv6High AND i.IPv6Low = @IPv6Low THEN NULL
					ELSE 'X'
				END,
				i.LastModifiedAt DESC

			IF @@ERROR <> 0 RETURN(1)	
			END

		--Next, search all NetworkInterface records
		IF @NetworkInterfaceID IS NULL 
			BEGIN
			SELECT TOP 1 @NetworkInterfaceID = i.NetworkInterfaceID,
				@Old_AssetID = AssetID
			FROM NetworkInterface_Recovery i (UPDLOCK)
			INNER JOIN DNS_Recovery d ON i.DNSID = d.DNSID 
			WHERE LEFT(d.DNSName+'.',CHARINDEX('.',d.DNSName+'.')-1) = LEFT(@DNSName+'.',CHARINDEX('.',@DNSName+'.')-1)
				AND (i.IPV4Nbr = @IPV4Nbr OR (i.IPv6High = @IPv6High AND i.IPv6Low = @IPv6Low))
				AND (i.MACAddress IS NULL OR @MACAddress IS NULL)
			--choose matching IPv6 then unassigned asset records then unassigned mac records 
			--then most recently updated
			ORDER BY
				CASE
					WHEN i.IPv6High = @IPv6High AND i.IPv6Low = @IPv6Low THEN NULL
					ELSE 'X'
				END,             
				CASE WHEN i.AssetID IS NULL THEN NULL ELSE 'X' END ASC,
				CASE WHEN MACAddress IS NULL THEN NULL ELSE 'X' END ASC, 
				LastModifiedAt DESC 	

			IF @@ERROR <> 0 RETURN(1)	
			END
		IF @NetworkInterfaceID IS NOT NULL
			SELECT @MatchType = 'DNSIP'
		END

	--Find network interface by IP only
	IF @NetworkInterfaceID IS NULL AND @IPV4Nbr IS NOT NULL
		BEGIN
		--First, search networkinterface records associated with asset
		IF @AssetID IS NOT NULL 
			BEGIN
			SELECT TOP 1 @NetworkInterfaceID = i.NetworkInterfaceID
			FROM NetworkInterface_Recovery i (UPDLOCK)
			LEFT OUTER JOIN DNS_Recovery d ON i.DNSID = d.DNSID 
			WHERE (i.IPV4Nbr = @IPV4Nbr OR (i.IPv6High = @IPv6High AND i.IPv6Low = @IPv6Low))
			AND i.AssetID = @AssetID
			AND (i.MACAddress IS NULL OR @MACAddress IS NULL)
			ORDER BY 
			CASE
				WHEN i.IPv6High = @IPv6High AND i.IPv6Low = @IPv6Low THEN NULL
				ELSE 'X'
			END ASC,
			i.LastModifiedAt DESC

			IF @@ERROR <> 0 RETURN(1)	
			END

		--Next, search all NetworkInterface records
		IF @NetworkInterfaceID IS NULL 
			BEGIN
			SELECT TOP 1 @NetworkInterfaceID = i.NetworkInterfaceID,
				@Old_AssetID = AssetID
			FROM NetworkInterface_Recovery i (UPDLOCK)
			LEFT OUTER JOIN DNS_Recovery d ON i.DNSID = d.DNSID 
			WHERE (i.IPV4Nbr = @IPV4Nbr OR (i.IPv6High = @IPv6High AND i.IPv6Low = @IPv6Low))
			AND (i.MACAddress IS NULL OR @MACAddress IS NULL)
			--choose IPv6 match then unassigned asset records then unassigned mac records 
			--then most recently updated
			ORDER BY
				CASE
					WHEN i.IPv6High = @IPv6High AND i.IPv6Low = @IPv6Low THEN NULL
					ELSE 'X'
				END ASC,
				CASE WHEN i.AssetID IS NULL THEN NULL ELSE 'X' END ASC,
				CASE WHEN MACAddress IS NULL THEN NULL ELSE 'X' END ASC,
				LastModifiedAt DESC 	

			IF @@ERROR <> 0 RETURN(1)	
			END
		IF @NetworkInterfaceID IS NOT NULL
			SELECT @MatchType = 'IP'
		END

	--If asset was found but interface was not found, then update first interface on found asset
	--where mac address is not provided or is null on existing interface. If MAC parameter is null
	--or all existing interfaces do not match MAC parameter, a new interface record will be added.
	IF @AssetID IS NOT NULL AND @NetworkInterfaceID IS NULL
		BEGIN
		SELECT TOP 1 @NetworkInterfaceID = i.NetworkInterfaceID
		FROM NetworkInterface_Recovery i (UPDLOCK)
		WHERE AssetID = @AssetID
		AND (i.MACAddress IS NULL OR @MACAddress IS NULL)
		--choose unassigned mac records first then by closest IP address 
		--then most recently updated
		ORDER BY CASE WHEN (MACAddress IS NULL OR @MACAddress IS NULL) THEN NULL ELSE 'X' END ASC, 
			ABS(i.IPV4Nbr - @IPV4Nbr) ASC,
			LastModifiedAt DESC 	

		IF @@ERROR <> 0 RETURN(1)	
		END
	--else if asset was not found and interface was found 
	ELSE IF @AssetID IS NULL AND @NetworkInterfaceID IS NOT NULL 
		BEGIN
		--If no asset info provided, use the assetid from the interface record
		IF @HostName IS NULL
			SELECT @AssetID = @Old_AssetID
		--else, by leaving assetid null, add asset
		END
	--else if asset was found and interface was found but interface is already assigned to different asset
	--consider how match was made before stealing interface away from asset
	ELSE IF @AssetID IS NOT NULL AND @NetworkInterfaceID IS NOT NULL
		AND @Old_AssetID IS NOT NULL AND @Old_AssetID != @AssetID
		BEGIN
		--(1) Unreliable match - ignore found interface and find best candidate interface on found asset 
		--    Conditions: Match was made using IP only or dynamic DNS and MAC address was either not 
		--    provided or null on found interface
		--(2) Unreliable match and no alternate interfaces found - Add new interface to found asset
		--    Conditions:  Match was made on IP and/or "dumb" DNS and MAC address was provided and 
		--    all existing interfaces have non-null, non-matching MAC addresses
		--(3) Reliable match/steal found interface away from another asset 
		--    Conditions: Exact MAC address match or any DNS match that isn't dynamic DNS containing IP

		--Scenario (1) --Unreliable match
		IF @MatchType = 'IP' OR (@MatchType IN ('DNSIP') AND @DNSName LIKE ('%' + REPLACE(@IPV4Address,'.','_') + '%'))
			BEGIN
			SELECT TOP 1 @NetworkInterfaceID = i.NetworkInterfaceID
			FROM NetworkInterface_Recovery i (UPDLOCK)
			WHERE AssetID = @AssetID
				AND (i.MACAddress IS NULL OR @MACAddress IS NULL)
			--choose unassigned mac records first then by closest IP address 
			--then most recently updated
			ORDER BY CASE WHEN (MACAddress IS NULL OR @MACAddress IS NULL) THEN NULL ELSE 'X' END ASC, 
				ABS(i.IPV4Nbr - @IPV4Nbr) ASC,
				LastModifiedAt DESC 	
		
			SELECT @SaveRowCnt = @@ROWCOUNT, @SaveErrNbr = @@ERROR
			IF @SaveErrNbr <> 0 RETURN(1)	

			--Scenario (2): No candidates so add new interface
			IF @SaveRowCnt = 0
				SELECT @NetworkInterfaceID = NULL
			END
		--else Scenario (3): Move found interface to found asset (default behavior)
		END

	--If interface was found, update else insert
	IF @NetworkInterfaceID IS NOT NULL 
		BEGIN
		UPDATE NetworkInterface_Recovery
		SET	FO_NetworkInterfaceID = @FO_NetworkInterfaceID
		WHERE NetworkInterfaceID = @NetworkInterfaceID
		
		IF @@ERROR <> 0 RETURN(1)	
		END
	
	SELECT @NetworkInterfaceID = NULL, @AssetID = NULL, @DNSID = NULL, @OSInfoProvided = NULL, @Old_AssetID = NULL, @MatchType = NULL, 
		@FO_NetworkInterfaceID = NULL
	FETCH NEXT FROM c
	INTO @FO_NetworkInterfaceID, @GUID, @HostName, @Domain, @DNSName, @IPV4Nbr, @IPV4Address, @HostNameResolved, @OSName, @MACAddress, @IPv6High, @IPv6Low
	END
	
CLOSE c
DEALLOCATE c

RETURN (0)

GO
