IF OBJECT_ID('iss_Failover_Import_Special_Pre') IS NOT NULL DROP PROCEDURE dbo.iss_Failover_Import_Special_Pre
go
CREATE PROCEDURE dbo.iss_Failover_Import_Special_Pre
AS
/* IBM Confidential - OCO Source Materials */
/* Copyright (c) IBM Corp. 2008 */
/* The source code for this program is not published or otherwise divested of its trade secrets, */
/* irrespective of what has been deposited with the U.S. Copyright Office. */ 
DECLARE @SaveErrNbr int, @SaveRowCnt int, @FirstError int, @RetVal int, @procname sysname 
SELECT @ProcName = OBJECT_NAME(@@ProcID)
SET NOCOUNT ON
-- iss_error error-number, severity, proc-name, relates-to-errorid, raise-params, errorid (OUT)

/*
 * These special steps should be done BEFORE the automated UPDATEs are run to 
 * ensure that related tables are renumbered properly. 
 */
------------------------------------------------------------------------------------
-- Groups
------------------------------------------------------------------------------------
--Renumber root group
UPDATE Groups_Recovery
SET FO_GroupID = (SELECT GroupID FROM Groups WHERE ParentGroupID IS NULL AND Deleted = 0)
WHERE ParentGroupID IS NULL AND Deleted = 0

------------------------------------------------------------------------------------
-- BinaryData
------------------------------------------------------------------------------------
--Renumber records matching fuzzy logic on what we consider unique
UPDATE BinaryData_Recovery
SET BinaryData_Recovery.FO_BinaryDataID = BinaryData.BinaryDataID
FROM BinaryData
WHERE BinaryData_Recovery.BinaryDataType = BinaryData.BinaryDataType
	AND ((BinaryData_Recovery.CheckSum = BinaryData.CheckSum AND BinaryData_Recovery.FileName = BinaryData.FileName)
	OR	(BinaryData_Recovery.CheckSum = BinaryData.CheckSum AND BinaryData.FileName IS NULL)
	OR	(BinaryData_Recovery.CheckSum IS NULL AND BinaryData_Recovery.FileName = BinaryData.FileName))
IF @@ERROR <> 0 RETURN(1)

------------------------------------------------------------------------------------
-- Component
------------------------------------------------------------------------------------
--Reassign sensors connected to a deleted EC to the 1st secondary EC found
UPDATE 	Component_Recovery
SET 	EventCollectorID = (SELECT TOP 1 ComponentID FROM Component WHERE RoleID = 8)
WHERE	EventCollectorID NOT IN (SELECT ComponentID FROM Component_Recovery)
AND	RoleID NOT IN (12, 25)
IF @@ERROR <> 0 RETURN(1)

--Reassign sensors connected to a deleted AM to NULL. These can't be reassigned directly in the db.
UPDATE 	Component_Recovery
SET 	EventCollectorID = NULL
WHERE	EventCollectorID NOT IN (SELECT ComponentID FROM Component_Recovery)
AND	RoleID IN (12, 25)
IF @@ERROR <> 0 RETURN(1)

--OptionFlags to 1 (Not managed)
--ECStatus to 0 (Offline)
IF EXISTS (SELECT 1 FROM Version WHERE AttributeName = 'IsSecondarySite' AND AttributeValue = 'true')
BEGIN  -- release sensors
	UPDATE Component_Recovery
	SET OptionFlags = OptionFlags | 1, 
	ECStatus = CASE ECStatus WHEN 1 THEN 0 ELSE ECStatus END
	FROM Component_Recovery
	IF @@ERROR <> 0 RETURN(1)
END
ELSE   -- manage sensors
BEGIN
	UPDATE Component_Recovery
	SET OptionFlags = (OptionFlags | 1) - 1, 
	ECStatus = CASE ECStatus WHEN 0 THEN 1 ELSE ECStatus END
	FROM Component_Recovery
	IF @@ERROR <> 0 RETURN(1)
END

------------------------------------------------------------------------------------
-- Component
------------------------------------------------------------------------------------
IF EXISTS (SELECT 1 FROM Version WHERE AttributeName = 'IsSecondarySite' AND AttributeValue = 'true')
	BEGIN
	EXEC @RetVal = iss_Failover_Import_Asset
	IF @RetVal <> 0 OR @@ERROR <> 0	RETURN(1)
	END
ELSE
	BEGIN
	--Match NetworkInterfaces (and associated asset-related tables) using iss_NetworkInterface_Identify
	--and update the appropriate _Recovery table with the PK.
	--Later during renumbering, these IDs will be renumbered in all associated tables, and then
	--later during UPDATE and INSERT, we will match the PK and SET any additional attributes these
	--records may have.
	DECLARE  	@GUID varchar(36),
				@HostName nvarchar(16),
				@Domain nvarchar(26),
				@DNSName nvarchar(254), 
				@IPV4Nbr numeric(10),
				@IPV4Address varchar(47),
				@HostNameResolved tinyint,
				@OSName nvarchar(64),
				@MACAddress varchar(17),
				@IPv6High	bigint,
				@IPv6Low	bigint,
				@AssetID	int,
				@NetworkInterfaceID int,
				@DNSID		int,
				@FO_AssetID	int,
				@FO_NetworkInterfaceID	int,
				@FO_DNSID	int

	DECLARE c CURSOR LOCAL FOR
	SELECT a.GUID, a.HostName, a.Domain, d.DNSName, dbo.iss_CalcIPNbrFNC(n.IPV4Address) AS IPV4Nbr, n.IPV4Address, 
		n.HostNameResolved, a.OSName, n.MACAddress, n.IPv6High, n.IPv6Low, 
		n.NetworkInterfaceID, a.AssetID, d.DNSID
	FROM NetworkInterface_Recovery n
	LEFT OUTER JOIN Asset_Recovery AS a ON n.AssetID = a.AssetID
	LEFT OUTER JOIN DNS_Recovery AS d ON n.DNSID = d.DNSID

	OPEN c

	FETCH NEXT FROM c INTO
		@GUID, @HostName, @Domain, @DNSName, @IPV4Nbr, @IPV4Address, 
		@HostNameResolved, @OSName, @MACAddress, @IPv6High, @IPv6Low, 
		@NetworkInterfaceID, @AssetID, @DNSID

	WHILE @@FETCH_STATUS = 0
		BEGIN
		SET @FO_AssetID = NULL
		SET @FO_NetworkInterfaceID = NULL
		SET @FO_DNSID = NULL

		EXEC @RetVal = iss_NetworkInterface_Identify
			@GUID, @HostName, @Domain, @DNSName, @IPV4Nbr, @IPV4Address, 
			@HostNameResolved, @OSName, @MACAddress, @IPv6High, @IPv6Low,
			@FO_AssetID OUTPUT, @FO_NetworkInterfaceID OUTPUT, @FO_DNSID OUTPUT
		IF @RetVal <> 0 OR @@ERROR <> 0	RETURN(1)

		UPDATE NetworkInterface_Recovery
		SET FO_NetworkInterfaceID = @FO_NetworkInterfaceID
		WHERE NetworkInterfaceID = @NetworkInterfaceID
		IF @@ERROR <> 0 RETURN(1)

		UPDATE Asset_Recovery
		SET FO_AssetID = @FO_AssetID
		FROM Asset_Recovery
		RIGHT OUTER JOIN NetworkInterface_Recovery ON Asset_Recovery.AssetID = NetworkInterface_Recovery.AssetID
		WHERE NetworkInterfaceID = @NetworkInterfaceID	
		IF @@ERROR <> 0 RETURN(1)

		UPDATE DNS_Recovery
		SET FO_DNSID = @FO_DNSID
		FROM DNS_Recovery
		RIGHT OUTER JOIN NetworkInterface_Recovery ON DNS_Recovery.DNSID = NetworkInterface_Recovery.DNSID
		WHERE NetworkInterfaceID = @NetworkInterfaceID
		IF @@ERROR <> 0 RETURN(1)

		FETCH NEXT FROM c INTO
			@GUID, @HostName, @Domain, @DNSName, @IPV4Nbr, @IPV4Address, 
			@HostNameResolved, @OSName, @MACAddress, @IPv6High, @IPv6Low, 
			@NetworkInterfaceID, @AssetID, @DNSID
	END

	CLOSE c
	DEALLOCATE c
	END

RETURN (0)

GO
