IF OBJECT_ID('iss_Failover_Import_Updates') IS NOT NULL DROP PROCEDURE dbo.iss_Failover_Import_Updates
go
CREATE PROCEDURE dbo.iss_Failover_Import_Updates
AS
/* IBM Confidential - OCO Source Materials */
/* Copyright (c) IBM Corp. 2007 */
/* The source code for this program is not published or otherwise divested of its trade secrets, */
/* irrespective of what has been deposited with the U.S. Copyright Office. */ 
DECLARE @SaveErrNbr int, @SaveRowCnt int, @FirstError int, @RetVal int, @procname sysname 
SELECT @ProcName = OBJECT_NAME(@@ProcID)
SET NOCOUNT ON
-- iss_error error-number, severity, proc-name, relates-to-errorid, raise-params, errorid (OUT)

DECLARE @max1 BIGINT

/********************************************************************************** 
 *                     RENUMBER AssetCriticality_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in AssetCriticality_Recovery */
/********************************************************************************** 
 *                     RENUMBER AssetFunction_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE AssetFunction_Recovery
SET AssetFunction_Recovery.FO_MergeCode = CASE WHEN AssetFunction_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE AssetFunction_Recovery.FO_MergeCode END, 
	AssetFunction_Recovery.FO_AssetFunctionID = AssetFunction.AssetFunctionID
FROM AssetFunction_Recovery
INNER JOIN AssetFunction ON 	(((AssetFunction_Recovery.AssetFunctionName = AssetFunction.AssetFunctionName) OR (AssetFunction_Recovery.AssetFunctionName IS NULL AND AssetFunction.AssetFunctionName IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(AssetFunction.AssetFunctionID),0) FROM AssetFunction)
UPDATE AssetFunction_Recovery
SET AssetFunction_Recovery.FO_AssetFunctionID = AssetFunction_Recovery.AssetFunctionID + @max1
FROM AssetFunction_Recovery
WHERE AssetFunction_Recovery.FO_AssetFunctionID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber AssetFunctionMember */ 
UPDATE r
SET r.AssetFunctionID = ISNULL(fo.FO_AssetFunctionID, r.AssetFunctionID), 
r.FO_MergeCode = CASE WHEN fo.AssetFunctionID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM AssetFunctionMember_Recovery r
LEFT OUTER JOIN AssetFunction_Recovery AS fo ON r.AssetFunctionID = fo.AssetFunctionID
WHERE r.AssetFunctionID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber TicketRule */ 
UPDATE r
SET r.AssetFunctionID = ISNULL(fo.FO_AssetFunctionID, r.AssetFunctionID), 
r.FO_MergeCode = CASE WHEN fo.AssetFunctionID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM TicketRule_Recovery r
LEFT OUTER JOIN AssetFunction_Recovery AS fo ON r.AssetFunctionID = fo.AssetFunctionID
WHERE r.AssetFunctionID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out AssetFunctionID for deleted FO_AssetFunctionID */ 
UPDATE TicketRule
SET AssetFunctionID = NULL
WHERE AssetFunctionID IN ( SELECT FO_AssetFunctionID FROM AssetFunction_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER AssetOwner_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE AssetOwner_Recovery
SET AssetOwner_Recovery.FO_MergeCode = CASE WHEN AssetOwner_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE AssetOwner_Recovery.FO_MergeCode END, 
	AssetOwner_Recovery.FO_AssetOwnerID = AssetOwner.AssetOwnerID
FROM AssetOwner_Recovery
INNER JOIN AssetOwner ON 	(((AssetOwner_Recovery.AssetOwnerName = AssetOwner.AssetOwnerName) OR (AssetOwner_Recovery.AssetOwnerName IS NULL AND AssetOwner.AssetOwnerName IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(AssetOwner.AssetOwnerID),0) FROM AssetOwner)
UPDATE AssetOwner_Recovery
SET AssetOwner_Recovery.FO_AssetOwnerID = AssetOwner_Recovery.AssetOwnerID + @max1
FROM AssetOwner_Recovery
WHERE AssetOwner_Recovery.FO_AssetOwnerID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Asset */ 
UPDATE r
SET r.AssetOwnerID = ISNULL(fo.FO_AssetOwnerID, r.AssetOwnerID), 
r.FO_MergeCode = CASE WHEN fo.AssetOwnerID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Asset_Recovery r
LEFT OUTER JOIN AssetOwner_Recovery AS fo ON r.AssetOwnerID = fo.AssetOwnerID
WHERE r.AssetOwnerID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out AssetOwnerID for deleted FO_AssetOwnerID */ 
UPDATE Asset
SET AssetOwnerID = NULL
WHERE AssetOwnerID IN ( SELECT FO_AssetOwnerID FROM AssetOwner_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER Asset_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in Asset_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Asset.AssetID),0) FROM Asset)
UPDATE Asset_Recovery
SET Asset_Recovery.FO_AssetID = Asset_Recovery.AssetID + @max1
FROM Asset_Recovery
WHERE Asset_Recovery.FO_AssetID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber AssetFunctionMember */ 
UPDATE r
SET r.AssetID = ISNULL(fo.FO_AssetID, r.AssetID), 
r.FO_MergeCode = CASE WHEN fo.AssetID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM AssetFunctionMember_Recovery r
LEFT OUTER JOIN Asset_Recovery AS fo ON r.AssetID = fo.AssetID
WHERE r.AssetID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber NetworkInterface */ 
UPDATE r
SET r.AssetID = ISNULL(fo.FO_AssetID, r.AssetID), 
r.FO_MergeCode = CASE WHEN fo.AssetID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM NetworkInterface_Recovery r
LEFT OUTER JOIN Asset_Recovery AS fo ON r.AssetID = fo.AssetID
WHERE r.AssetID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out AssetID for deleted FO_AssetID */ 
UPDATE NetworkInterface
SET AssetID = NULL
WHERE AssetID IN ( SELECT FO_AssetID FROM Asset_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER AssetFunctionMember_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in AssetFunctionMember_Recovery */
/********************************************************************************** 
 *                     RENUMBER Certificate_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in Certificate_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Certificate.CertificateID),0) FROM Certificate)
UPDATE Certificate_Recovery
SET Certificate_Recovery.FO_CertificateID = Certificate_Recovery.CertificateID + @max1
FROM Certificate_Recovery
WHERE Certificate_Recovery.FO_CertificateID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ComponentCertificate */ 
UPDATE r
SET r.CertificateID = ISNULL(fo.FO_CertificateID, r.CertificateID), 
r.FO_MergeCode = CASE WHEN fo.CertificateID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ComponentCertificate_Recovery r
LEFT OUTER JOIN Certificate_Recovery AS fo ON r.CertificateID = fo.CertificateID
WHERE r.CertificateID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER ComponentCertificate_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE ComponentCertificate_Recovery
SET ComponentCertificate_Recovery.FO_MergeCode = CASE WHEN ComponentCertificate_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE ComponentCertificate_Recovery.FO_MergeCode END, 
	ComponentCertificate_Recovery.FO_ComponentCertificateID = ComponentCertificate.ComponentCertificateID
FROM ComponentCertificate_Recovery
INNER JOIN ComponentCertificate ON 	(((ComponentCertificate_Recovery.GUID = ComponentCertificate.GUID) OR (ComponentCertificate_Recovery.GUID IS NULL AND ComponentCertificate.GUID IS NULL)) AND 
		((ComponentCertificate_Recovery.Purpose = ComponentCertificate.Purpose) OR (ComponentCertificate_Recovery.Purpose IS NULL AND ComponentCertificate.Purpose IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(ComponentCertificate.ComponentCertificateID),0) FROM ComponentCertificate)
UPDATE ComponentCertificate_Recovery
SET ComponentCertificate_Recovery.FO_ComponentCertificateID = ComponentCertificate_Recovery.ComponentCertificateID + @max1
FROM ComponentCertificate_Recovery
WHERE ComponentCertificate_Recovery.FO_ComponentCertificateID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER DNS_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE DNS_Recovery
SET DNS_Recovery.FO_MergeCode = CASE WHEN DNS_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE DNS_Recovery.FO_MergeCode END, 
	DNS_Recovery.FO_DNSID = DNS.DNSID
FROM DNS_Recovery
INNER JOIN DNS ON 	(((DNS_Recovery.DNSName = DNS.DNSName) OR (DNS_Recovery.DNSName IS NULL AND DNS.DNSName IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(DNS.DNSID),0) FROM DNS)
UPDATE DNS_Recovery
SET DNS_Recovery.FO_DNSID = DNS_Recovery.DNSID + @max1
FROM DNS_Recovery
WHERE DNS_Recovery.FO_DNSID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber NetworkInterface */ 
UPDATE r
SET r.DNSID = ISNULL(fo.FO_DNSID, r.DNSID), 
r.FO_MergeCode = CASE WHEN fo.DNSID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM NetworkInterface_Recovery r
LEFT OUTER JOIN DNS_Recovery AS fo ON r.DNSID = fo.DNSID
WHERE r.DNSID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out DNSID for deleted FO_DNSID */ 
UPDATE NetworkInterface
SET DNSID = NULL
WHERE DNSID IN ( SELECT FO_DNSID FROM DNS_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER GroupRule_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in GroupRule_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(GroupRule.RuleID),0) FROM GroupRule)
UPDATE GroupRule_Recovery
SET GroupRule_Recovery.FO_RuleID = GroupRule_Recovery.RuleID + @max1
FROM GroupRule_Recovery
WHERE GroupRule_Recovery.FO_RuleID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Groups */ 
UPDATE r
SET r.RuleID = ISNULL(fo.FO_RuleID, r.RuleID), 
r.FO_MergeCode = CASE WHEN fo.RuleID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Groups_Recovery r
LEFT OUTER JOIN GroupRule_Recovery AS fo ON r.RuleID = fo.RuleID
WHERE r.RuleID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out RuleID for deleted FO_RuleID */ 
UPDATE Groups
SET RuleID = NULL
WHERE RuleID IN ( SELECT FO_RuleID FROM GroupRule_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER LicContactInfo_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in LicContactInfo_Recovery */
/********************************************************************************** 
 *                     RENUMBER Namespace_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE Namespace_Recovery
SET Namespace_Recovery.FO_MergeCode = CASE WHEN Namespace_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE Namespace_Recovery.FO_MergeCode END, 
	Namespace_Recovery.FO_NamespaceID = Namespace.NamespaceID
FROM Namespace_Recovery
INNER JOIN Namespace ON 	(((Namespace_Recovery.Namespace = Namespace.Namespace) OR (Namespace_Recovery.Namespace IS NULL AND Namespace.Namespace IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Namespace.NamespaceID),0) FROM Namespace)
UPDATE Namespace_Recovery
SET Namespace_Recovery.FO_NamespaceID = Namespace_Recovery.NamespaceID + @max1
FROM Namespace_Recovery
WHERE Namespace_Recovery.FO_NamespaceID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ComponentSubscription */ 
UPDATE r
SET r.NamespaceID = ISNULL(fo.FO_NamespaceID, r.NamespaceID), 
r.FO_MergeCode = CASE WHEN fo.NamespaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ComponentSubscription_Recovery r
LEFT OUTER JOIN Namespace_Recovery AS fo ON r.NamespaceID = fo.NamespaceID
WHERE r.NamespaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ComponentSubscription */ 
UPDATE r
SET r.ServiceNamespaceID = ISNULL(fo.FO_NamespaceID, r.ServiceNamespaceID), 
r.FO_MergeCode = CASE WHEN fo.NamespaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ComponentSubscription_Recovery r
LEFT OUTER JOIN Namespace_Recovery AS fo ON r.ServiceNamespaceID = fo.NamespaceID
WHERE r.ServiceNamespaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeployedPolicy */ 
UPDATE r
SET r.NamespaceID = ISNULL(fo.FO_NamespaceID, r.NamespaceID), 
r.FO_MergeCode = CASE WHEN fo.NamespaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeployedPolicy_Recovery r
LEFT OUTER JOIN Namespace_Recovery AS fo ON r.NamespaceID = fo.NamespaceID
WHERE r.NamespaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DocumentReceipt */ 
UPDATE r
SET r.NamespaceID = ISNULL(fo.FO_NamespaceID, r.NamespaceID), 
r.FO_MergeCode = CASE WHEN fo.NamespaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DocumentReceipt_Recovery r
LEFT OUTER JOIN Namespace_Recovery AS fo ON r.NamespaceID = fo.NamespaceID
WHERE r.NamespaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber GlobalObject */ 
UPDATE r
SET r.NamespaceID = ISNULL(fo.FO_NamespaceID, r.NamespaceID), 
r.FO_MergeCode = CASE WHEN fo.NamespaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM GlobalObject_Recovery r
LEFT OUTER JOIN Namespace_Recovery AS fo ON r.NamespaceID = fo.NamespaceID
WHERE r.NamespaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber PolicyDocumentCollection */ 
UPDATE r
SET r.NamespaceID = ISNULL(fo.FO_NamespaceID, r.NamespaceID), 
r.FO_MergeCode = CASE WHEN fo.NamespaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM PolicyDocumentCollection_Recovery r
LEFT OUTER JOIN Namespace_Recovery AS fo ON r.NamespaceID = fo.NamespaceID
WHERE r.NamespaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber PolicyRepository */ 
UPDATE r
SET r.NamespaceID = ISNULL(fo.FO_NamespaceID, r.NamespaceID), 
r.FO_MergeCode = CASE WHEN fo.NamespaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM PolicyRepository_Recovery r
LEFT OUTER JOIN Namespace_Recovery AS fo ON r.NamespaceID = fo.NamespaceID
WHERE r.NamespaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber PolicySandbox */ 
UPDATE r
SET r.NamespaceID = ISNULL(fo.FO_NamespaceID, r.NamespaceID), 
r.FO_MergeCode = CASE WHEN fo.NamespaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM PolicySandbox_Recovery r
LEFT OUTER JOIN Namespace_Recovery AS fo ON r.NamespaceID = fo.NamespaceID
WHERE r.NamespaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber SubTask */ 
UPDATE r
SET r.SubTaskNamespaceID = ISNULL(fo.FO_NamespaceID, r.SubTaskNamespaceID), 
r.FO_MergeCode = CASE WHEN fo.NamespaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM SubTask_Recovery r
LEFT OUTER JOIN Namespace_Recovery AS fo ON r.SubTaskNamespaceID = fo.NamespaceID
WHERE r.SubTaskNamespaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Task */ 
UPDATE r
SET r.TaskNamespaceID = ISNULL(fo.FO_NamespaceID, r.TaskNamespaceID), 
r.FO_MergeCode = CASE WHEN fo.NamespaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Task_Recovery r
LEFT OUTER JOIN Namespace_Recovery AS fo ON r.TaskNamespaceID = fo.NamespaceID
WHERE r.TaskNamespaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER NetworkInterface_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in NetworkInterface_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(NetworkInterface.NetworkInterfaceID),0) FROM NetworkInterface)
UPDATE NetworkInterface_Recovery
SET NetworkInterface_Recovery.FO_NetworkInterfaceID = NetworkInterface_Recovery.NetworkInterfaceID + @max1
FROM NetworkInterface_Recovery
WHERE NetworkInterface_Recovery.FO_NetworkInterfaceID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ActionDetails */ 
UPDATE r
SET r.NetworkInterfaceID = ISNULL(fo.FO_NetworkInterfaceID, r.NetworkInterfaceID), 
r.FO_MergeCode = CASE WHEN fo.NetworkInterfaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ActionDetails_Recovery r
LEFT OUTER JOIN NetworkInterface_Recovery AS fo ON r.NetworkInterfaceID = fo.NetworkInterfaceID
WHERE r.NetworkInterfaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out NetworkInterfaceID for deleted FO_NetworkInterfaceID */ 
UPDATE ActionDetails
SET NetworkInterfaceID = NULL
WHERE NetworkInterfaceID IN ( SELECT FO_NetworkInterfaceID FROM NetworkInterface_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber Component */ 
UPDATE r
SET r.NetworkInterfaceID = ISNULL(fo.FO_NetworkInterfaceID, r.NetworkInterfaceID), 
r.FO_MergeCode = CASE WHEN fo.NetworkInterfaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Component_Recovery r
LEFT OUTER JOIN NetworkInterface_Recovery AS fo ON r.NetworkInterfaceID = fo.NetworkInterfaceID
WHERE r.NetworkInterfaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber GroupHostLinks */ 
UPDATE r
SET r.NetworkInterfaceID = ISNULL(fo.FO_NetworkInterfaceID, r.NetworkInterfaceID), 
r.FO_MergeCode = CASE WHEN fo.NetworkInterfaceID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM GroupHostLinks_Recovery r
LEFT OUTER JOIN NetworkInterface_Recovery AS fo ON r.NetworkInterfaceID = fo.NetworkInterfaceID
WHERE r.NetworkInterfaceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER PermissionAction_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE PermissionAction_Recovery
SET PermissionAction_Recovery.FO_MergeCode = CASE WHEN PermissionAction_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE PermissionAction_Recovery.FO_MergeCode END, 
	PermissionAction_Recovery.FO_PermissionActionID = PermissionAction.PermissionActionID
FROM PermissionAction_Recovery
INNER JOIN PermissionAction ON 	(((PermissionAction_Recovery.PermissionActionName = PermissionAction.PermissionActionName) OR (PermissionAction_Recovery.PermissionActionName IS NULL AND PermissionAction.PermissionActionName IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(PermissionAction.PermissionActionID),0) FROM PermissionAction)
UPDATE PermissionAction_Recovery
SET PermissionAction_Recovery.FO_PermissionActionID = PermissionAction_Recovery.PermissionActionID + @max1
FROM PermissionAction_Recovery
WHERE PermissionAction_Recovery.FO_PermissionActionID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber GrantList */ 
UPDATE r
SET r.PermissionActionID = ISNULL(fo.FO_PermissionActionID, r.PermissionActionID), 
r.FO_MergeCode = CASE WHEN fo.PermissionActionID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM GrantList_Recovery r
LEFT OUTER JOIN PermissionAction_Recovery AS fo ON r.PermissionActionID = fo.PermissionActionID
WHERE r.PermissionActionID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER PermissionTarget_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE PermissionTarget_Recovery
SET PermissionTarget_Recovery.FO_MergeCode = CASE WHEN PermissionTarget_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE PermissionTarget_Recovery.FO_MergeCode END, 
	PermissionTarget_Recovery.FO_PermissionTargetID = PermissionTarget.PermissionTargetID
FROM PermissionTarget_Recovery
INNER JOIN PermissionTarget ON 	(((PermissionTarget_Recovery.PermissionTargetName = PermissionTarget.PermissionTargetName) OR (PermissionTarget_Recovery.PermissionTargetName IS NULL AND PermissionTarget.PermissionTargetName IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(PermissionTarget.PermissionTargetID),0) FROM PermissionTarget)
UPDATE PermissionTarget_Recovery
SET PermissionTarget_Recovery.FO_PermissionTargetID = PermissionTarget_Recovery.PermissionTargetID + @max1
FROM PermissionTarget_Recovery
WHERE PermissionTarget_Recovery.FO_PermissionTargetID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber GrantList */ 
UPDATE r
SET r.PermissionTargetID = ISNULL(fo.FO_PermissionTargetID, r.PermissionTargetID), 
r.FO_MergeCode = CASE WHEN fo.PermissionTargetID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM GrantList_Recovery r
LEFT OUTER JOIN PermissionTarget_Recovery AS fo ON r.PermissionTargetID = fo.PermissionTargetID
WHERE r.PermissionTargetID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER Principal_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in Principal_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Principal.PrincipalID),0) FROM Principal)
UPDATE Principal_Recovery
SET Principal_Recovery.FO_PrincipalID = Principal_Recovery.PrincipalID + @max1
FROM Principal_Recovery
WHERE Principal_Recovery.FO_PrincipalID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ACL */ 
UPDATE r
SET r.OwnerPrincipalID = ISNULL(fo.FO_PrincipalID, r.OwnerPrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ACL_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.OwnerPrincipalID = fo.PrincipalID
WHERE r.OwnerPrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out OwnerPrincipalID for deleted FO_PrincipalID */ 
UPDATE ACL
SET OwnerPrincipalID = NULL
WHERE OwnerPrincipalID IN ( SELECT FO_PrincipalID FROM Principal_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber BinaryData */ 
UPDATE r
SET r.LastModifiedByPrincipalID = ISNULL(fo.FO_PrincipalID, r.LastModifiedByPrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM BinaryData_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.LastModifiedByPrincipalID = fo.PrincipalID
WHERE r.LastModifiedByPrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out LastModifiedByPrincipalID for deleted FO_PrincipalID */ 
UPDATE BinaryData
SET LastModifiedByPrincipalID = NULL
WHERE LastModifiedByPrincipalID IN ( SELECT FO_PrincipalID FROM Principal_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeployedPolicy */ 
UPDATE r
SET r.DeployedByPrincipalID = ISNULL(fo.FO_PrincipalID, r.DeployedByPrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeployedPolicy_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.DeployedByPrincipalID = fo.PrincipalID
WHERE r.DeployedByPrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out DeployedByPrincipalID for deleted FO_PrincipalID */ 
UPDATE DeployedPolicy
SET DeployedByPrincipalID = NULL
WHERE DeployedByPrincipalID IN ( SELECT FO_PrincipalID FROM Principal_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeploymentJob */ 
UPDATE r
SET r.SchedulerPrincipalID = ISNULL(fo.FO_PrincipalID, r.SchedulerPrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeploymentJob_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.SchedulerPrincipalID = fo.PrincipalID
WHERE r.SchedulerPrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out SchedulerPrincipalID for deleted FO_PrincipalID */ 
UPDATE DeploymentJob
SET SchedulerPrincipalID = NULL
WHERE SchedulerPrincipalID IN ( SELECT FO_PrincipalID FROM Principal_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber GrantList */ 
UPDATE r
SET r.PrincipalID = ISNULL(fo.FO_PrincipalID, r.PrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM GrantList_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.PrincipalID = fo.PrincipalID
WHERE r.PrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber NTGroup */ 
UPDATE r
SET r.PrincipalID = ISNULL(fo.FO_PrincipalID, r.PrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM NTGroup_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.PrincipalID = fo.PrincipalID
WHERE r.PrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber PolicyRepositoryVersion */ 
UPDATE r
SET r.LastModifiedByPrincipalID = ISNULL(fo.FO_PrincipalID, r.LastModifiedByPrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM PolicyRepositoryVersion_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.LastModifiedByPrincipalID = fo.PrincipalID
WHERE r.LastModifiedByPrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out LastModifiedByPrincipalID for deleted FO_PrincipalID */ 
UPDATE PolicyRepositoryVersion
SET LastModifiedByPrincipalID = NULL
WHERE LastModifiedByPrincipalID IN ( SELECT FO_PrincipalID FROM Principal_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber ScheduledJob */ 
UPDATE r
SET r.ScheduledByPrincipalID = ISNULL(fo.FO_PrincipalID, r.ScheduledByPrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ScheduledJob_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.ScheduledByPrincipalID = fo.PrincipalID
WHERE r.ScheduledByPrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber SPUserGroup */ 
UPDATE r
SET r.PrincipalID = ISNULL(fo.FO_PrincipalID, r.PrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM SPUserGroup_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.PrincipalID = fo.PrincipalID
WHERE r.PrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber SPUserGroupMember */ 
UPDATE r
SET r.PrincipalID = ISNULL(fo.FO_PrincipalID, r.PrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM SPUserGroupMember_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.PrincipalID = fo.PrincipalID
WHERE r.PrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber SPUserGroupMember */ 
UPDATE r
SET r.SPUserGroupPrincipalID = ISNULL(fo.FO_PrincipalID, r.SPUserGroupPrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM SPUserGroupMember_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.SPUserGroupPrincipalID = fo.PrincipalID
WHERE r.SPUserGroupPrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber TicketRule */ 
UPDATE r
SET r.TicketOwnerID = ISNULL(fo.FO_PrincipalID, r.TicketOwnerID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM TicketRule_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.TicketOwnerID = fo.PrincipalID
WHERE r.TicketOwnerID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out TicketOwnerID for deleted FO_PrincipalID */ 
UPDATE TicketRule
SET TicketOwnerID = NULL
WHERE TicketOwnerID IN ( SELECT FO_PrincipalID FROM Principal_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber Users */ 
UPDATE r
SET r.PrincipalID = ISNULL(fo.FO_PrincipalID, r.PrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Users_Recovery r
LEFT OUTER JOIN Principal_Recovery AS fo ON r.PrincipalID = fo.PrincipalID
WHERE r.PrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER ACL_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in ACL_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(ACL.ACLID),0) FROM ACL)
UPDATE ACL_Recovery
SET ACL_Recovery.FO_ACLID = ACL_Recovery.ACLID + @max1
FROM ACL_Recovery
WHERE ACL_Recovery.FO_ACLID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber GrantList */ 
UPDATE r
SET r.ACLID = ISNULL(fo.FO_ACLID, r.ACLID), 
r.FO_MergeCode = CASE WHEN fo.ACLID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM GrantList_Recovery r
LEFT OUTER JOIN ACL_Recovery AS fo ON r.ACLID = fo.ACLID
WHERE r.ACLID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Groups */ 
UPDATE r
SET r.ACLID = ISNULL(fo.FO_ACLID, r.ACLID), 
r.FO_MergeCode = CASE WHEN fo.ACLID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Groups_Recovery r
LEFT OUTER JOIN ACL_Recovery AS fo ON r.ACLID = fo.ACLID
WHERE r.ACLID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ACLID for deleted FO_ACLID */ 
UPDATE Groups
SET ACLID = NULL
WHERE ACLID IN ( SELECT FO_ACLID FROM ACL_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber ObjectACL */ 
UPDATE r
SET r.ACLID = ISNULL(fo.FO_ACLID, r.ACLID), 
r.FO_MergeCode = CASE WHEN fo.ACLID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ObjectACL_Recovery r
LEFT OUTER JOIN ACL_Recovery AS fo ON r.ACLID = fo.ACLID
WHERE r.ACLID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Policy */ 
UPDATE r
SET r.ACLID = ISNULL(fo.FO_ACLID, r.ACLID), 
r.FO_MergeCode = CASE WHEN fo.ACLID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Policy_Recovery r
LEFT OUTER JOIN ACL_Recovery AS fo ON r.ACLID = fo.ACLID
WHERE r.ACLID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ACLID for deleted FO_ACLID */ 
UPDATE Policy
SET ACLID = NULL
WHERE ACLID IN ( SELECT FO_ACLID FROM ACL_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber Response */ 
UPDATE r
SET r.ACLID = ISNULL(fo.FO_ACLID, r.ACLID), 
r.FO_MergeCode = CASE WHEN fo.ACLID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Response_Recovery r
LEFT OUTER JOIN ACL_Recovery AS fo ON r.ACLID = fo.ACLID
WHERE r.ACLID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ACLID for deleted FO_ACLID */ 
UPDATE Response
SET ACLID = NULL
WHERE ACLID IN ( SELECT FO_ACLID FROM ACL_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER BinaryData_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in BinaryData_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(BinaryData.BinaryDataID),0) FROM BinaryData)
UPDATE BinaryData_Recovery
SET BinaryData_Recovery.FO_BinaryDataID = BinaryData_Recovery.BinaryDataID + @max1
FROM BinaryData_Recovery
WHERE BinaryData_Recovery.FO_BinaryDataID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Component */ 
UPDATE r
SET r.PropertyFileID = ISNULL(fo.FO_BinaryDataID, r.PropertyFileID), 
r.FO_MergeCode = CASE WHEN fo.BinaryDataID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Component_Recovery r
LEFT OUTER JOIN BinaryData_Recovery AS fo ON r.PropertyFileID = fo.BinaryDataID
WHERE r.PropertyFileID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out PropertyFileID for deleted FO_BinaryDataID */ 
UPDATE Component
SET PropertyFileID = NULL
WHERE PropertyFileID IN ( SELECT FO_BinaryDataID FROM BinaryData_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber DesktopAgentVersion */ 
UPDATE r
SET r.ReadmeFileID = ISNULL(fo.FO_BinaryDataID, r.ReadmeFileID), 
r.FO_MergeCode = CASE WHEN fo.BinaryDataID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DesktopAgentVersion_Recovery r
LEFT OUTER JOIN BinaryData_Recovery AS fo ON r.ReadmeFileID = fo.BinaryDataID
WHERE r.ReadmeFileID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ReadmeFileID for deleted FO_BinaryDataID */ 
UPDATE DesktopAgentVersion
SET ReadmeFileID = NULL
WHERE ReadmeFileID IN ( SELECT FO_BinaryDataID FROM BinaryData_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber GlobalObject */ 
UPDATE r
SET r.BinaryDataID = ISNULL(fo.FO_BinaryDataID, r.BinaryDataID), 
r.FO_MergeCode = CASE WHEN fo.BinaryDataID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM GlobalObject_Recovery r
LEFT OUTER JOIN BinaryData_Recovery AS fo ON r.BinaryDataID = fo.BinaryDataID
WHERE r.BinaryDataID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber License */ 
UPDATE r
SET r.BinaryDataID = ISNULL(fo.FO_BinaryDataID, r.BinaryDataID), 
r.FO_MergeCode = CASE WHEN fo.BinaryDataID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM License_Recovery r
LEFT OUTER JOIN BinaryData_Recovery AS fo ON r.BinaryDataID = fo.BinaryDataID
WHERE r.BinaryDataID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out BinaryDataID for deleted FO_BinaryDataID */ 
UPDATE License
SET BinaryDataID = NULL
WHERE BinaryDataID IN ( SELECT FO_BinaryDataID FROM BinaryData_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber Policy */ 
UPDATE r
SET r.BinaryDataID = ISNULL(fo.FO_BinaryDataID, r.BinaryDataID), 
r.FO_MergeCode = CASE WHEN fo.BinaryDataID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Policy_Recovery r
LEFT OUTER JOIN BinaryData_Recovery AS fo ON r.BinaryDataID = fo.BinaryDataID
WHERE r.BinaryDataID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out BinaryDataID for deleted FO_BinaryDataID */ 
UPDATE Policy
SET BinaryDataID = NULL
WHERE BinaryDataID IN ( SELECT FO_BinaryDataID FROM BinaryData_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber PolicyDocumentCollection */ 
UPDATE r
SET r.BinaryDataID = ISNULL(fo.FO_BinaryDataID, r.BinaryDataID), 
r.FO_MergeCode = CASE WHEN fo.BinaryDataID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM PolicyDocumentCollection_Recovery r
LEFT OUTER JOIN BinaryData_Recovery AS fo ON r.BinaryDataID = fo.BinaryDataID
WHERE r.BinaryDataID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber PolicyRepositoryVersion */ 
UPDATE r
SET r.BinaryDataID = ISNULL(fo.FO_BinaryDataID, r.BinaryDataID), 
r.FO_MergeCode = CASE WHEN fo.BinaryDataID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM PolicyRepositoryVersion_Recovery r
LEFT OUTER JOIN BinaryData_Recovery AS fo ON r.BinaryDataID = fo.BinaryDataID
WHERE r.BinaryDataID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber PolicySandbox */ 
UPDATE r
SET r.BinaryDataID = ISNULL(fo.FO_BinaryDataID, r.BinaryDataID), 
r.FO_MergeCode = CASE WHEN fo.BinaryDataID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM PolicySandbox_Recovery r
LEFT OUTER JOIN BinaryData_Recovery AS fo ON r.BinaryDataID = fo.BinaryDataID
WHERE r.BinaryDataID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Response */ 
UPDATE r
SET r.BinaryDataID = ISNULL(fo.FO_BinaryDataID, r.BinaryDataID), 
r.FO_MergeCode = CASE WHEN fo.BinaryDataID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Response_Recovery r
LEFT OUTER JOIN BinaryData_Recovery AS fo ON r.BinaryDataID = fo.BinaryDataID
WHERE r.BinaryDataID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out BinaryDataID for deleted FO_BinaryDataID */ 
UPDATE Response
SET BinaryDataID = NULL
WHERE BinaryDataID IN ( SELECT FO_BinaryDataID FROM BinaryData_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER DesktopAgentVersion_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in DesktopAgentVersion_Recovery */
/********************************************************************************** 
 *                     RENUMBER GrantList_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE GrantList_Recovery
SET GrantList_Recovery.FO_MergeCode = CASE WHEN GrantList_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE GrantList_Recovery.FO_MergeCode END, 
	GrantList_Recovery.FO_GrantListID = GrantList.GrantListID
FROM GrantList_Recovery
INNER JOIN GrantList ON 	(((GrantList_Recovery.ACLID = GrantList.ACLID) OR (GrantList_Recovery.ACLID IS NULL AND GrantList.ACLID IS NULL)) AND 
		((GrantList_Recovery.PrincipalID = GrantList.PrincipalID) OR (GrantList_Recovery.PrincipalID IS NULL AND GrantList.PrincipalID IS NULL)) AND 
		((GrantList_Recovery.PermissionTargetID = GrantList.PermissionTargetID) OR (GrantList_Recovery.PermissionTargetID IS NULL AND GrantList.PermissionTargetID IS NULL)) AND 
		((GrantList_Recovery.PermissionActionID = GrantList.PermissionActionID) OR (GrantList_Recovery.PermissionActionID IS NULL AND GrantList.PermissionActionID IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(GrantList.GrantListID),0) FROM GrantList)
UPDATE GrantList_Recovery
SET GrantList_Recovery.FO_GrantListID = GrantList_Recovery.GrantListID + @max1
FROM GrantList_Recovery
WHERE GrantList_Recovery.FO_GrantListID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER License_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in License_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(License.LicenseID),0) FROM License)
UPDATE License_Recovery
SET License_Recovery.FO_LicenseID = License_Recovery.LicenseID + @max1
FROM License_Recovery
WHERE License_Recovery.FO_LicenseID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Component */ 
UPDATE r
SET r.LicenseID = ISNULL(fo.FO_LicenseID, r.LicenseID), 
r.FO_MergeCode = CASE WHEN fo.LicenseID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Component_Recovery r
LEFT OUTER JOIN License_Recovery AS fo ON r.LicenseID = fo.LicenseID
WHERE r.LicenseID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out LicenseID for deleted FO_LicenseID */ 
UPDATE Component
SET LicenseID = NULL
WHERE LicenseID IN ( SELECT FO_LicenseID FROM License_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber License */ 
UPDATE r
SET r.NewLicenseID = ISNULL(fo.FO_LicenseID, r.NewLicenseID), 
r.FO_MergeCode = CASE WHEN fo.LicenseID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM License_Recovery r
LEFT OUTER JOIN License_Recovery AS fo ON r.NewLicenseID = fo.LicenseID
WHERE r.NewLicenseID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out NewLicenseID for deleted FO_LicenseID */ 
UPDATE License
SET NewLicenseID = NULL
WHERE NewLicenseID IN ( SELECT FO_LicenseID FROM License_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER NTGroup_Recovery
 **********************************************************************************/
/*
 * There is no identity to renumber in NTGroup
 */

/********************************************************************************** 
 *                     RENUMBER ObjectAcl_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in ObjectAcl_Recovery */
/********************************************************************************** 
 *                     RENUMBER Policy_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in Policy_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Policy.PolicyID),0) FROM Policy)
UPDATE Policy_Recovery
SET Policy_Recovery.FO_PolicyID = Policy_Recovery.PolicyID + @max1
FROM Policy_Recovery
WHERE Policy_Recovery.FO_PolicyID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Component */ 
UPDATE r
SET r.LastPushedPolicyID = ISNULL(fo.FO_PolicyID, r.LastPushedPolicyID), 
r.FO_MergeCode = CASE WHEN fo.PolicyID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Component_Recovery r
LEFT OUTER JOIN Policy_Recovery AS fo ON r.LastPushedPolicyID = fo.PolicyID
WHERE r.LastPushedPolicyID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out LastPushedPolicyID for deleted FO_PolicyID */ 
UPDATE Component
SET LastPushedPolicyID = NULL
WHERE LastPushedPolicyID IN ( SELECT FO_PolicyID FROM Policy_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber GroupPolicy */ 
UPDATE r
SET r.PolicyID = ISNULL(fo.FO_PolicyID, r.PolicyID), 
r.FO_MergeCode = CASE WHEN fo.PolicyID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM GroupPolicy_Recovery r
LEFT OUTER JOIN Policy_Recovery AS fo ON r.PolicyID = fo.PolicyID
WHERE r.PolicyID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER PolicyDocumentCollection_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in PolicyDocumentCollection_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(PolicyDocumentCollection.PolicyDocumentCollectionID),0) FROM PolicyDocumentCollection)
UPDATE PolicyDocumentCollection_Recovery
SET PolicyDocumentCollection_Recovery.FO_PolicyDocumentCollectionID = PolicyDocumentCollection_Recovery.PolicyDocumentCollectionID + @max1
FROM PolicyDocumentCollection_Recovery
WHERE PolicyDocumentCollection_Recovery.FO_PolicyDocumentCollectionID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER Response_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in Response_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Response.ResponseID),0) FROM Response)
UPDATE Response_Recovery
SET Response_Recovery.FO_ResponseID = Response_Recovery.ResponseID + @max1
FROM Response_Recovery
WHERE Response_Recovery.FO_ResponseID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Component */ 
UPDATE r
SET r.LastPushedResponseID = ISNULL(fo.FO_ResponseID, r.LastPushedResponseID), 
r.FO_MergeCode = CASE WHEN fo.ResponseID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Component_Recovery r
LEFT OUTER JOIN Response_Recovery AS fo ON r.LastPushedResponseID = fo.ResponseID
WHERE r.LastPushedResponseID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out LastPushedResponseID for deleted FO_ResponseID */ 
UPDATE Component
SET LastPushedResponseID = NULL
WHERE LastPushedResponseID IN ( SELECT FO_ResponseID FROM Response_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER Schedule_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in Schedule_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Schedule.ScheduleID),0) FROM Schedule)
UPDATE Schedule_Recovery
SET Schedule_Recovery.FO_ScheduleID = Schedule_Recovery.ScheduleID + @max1
FROM Schedule_Recovery
WHERE Schedule_Recovery.FO_ScheduleID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ActionDetails */ 
UPDATE r
SET r.ScheduleID = ISNULL(fo.FO_ScheduleID, r.ScheduleID), 
r.FO_MergeCode = CASE WHEN fo.ScheduleID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ActionDetails_Recovery r
LEFT OUTER JOIN Schedule_Recovery AS fo ON r.ScheduleID = fo.ScheduleID
WHERE r.ScheduleID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ScheduleID for deleted FO_ScheduleID */ 
UPDATE ActionDetails
SET ScheduleID = NULL
WHERE ScheduleID IN ( SELECT FO_ScheduleID FROM Schedule_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER ScheduledJobTrigger_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in ScheduledJobTrigger_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(ScheduledJobTrigger.ScheduledJobTriggerID),0) FROM ScheduledJobTrigger)
UPDATE ScheduledJobTrigger_Recovery
SET ScheduledJobTrigger_Recovery.FO_ScheduledJobTriggerID = ScheduledJobTrigger_Recovery.ScheduledJobTriggerID + @max1
FROM ScheduledJobTrigger_Recovery
WHERE ScheduledJobTrigger_Recovery.FO_ScheduledJobTriggerID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ScheduledJob */ 
UPDATE r
SET r.ScheduledJobTriggerID = ISNULL(fo.FO_ScheduledJobTriggerID, r.ScheduledJobTriggerID), 
r.FO_MergeCode = CASE WHEN fo.ScheduledJobTriggerID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ScheduledJob_Recovery r
LEFT OUTER JOIN ScheduledJobTrigger_Recovery AS fo ON r.ScheduledJobTriggerID = fo.ScheduledJobTriggerID
WHERE r.ScheduledJobTriggerID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ScheduledJobTriggerID for deleted FO_ScheduledJobTriggerID */ 
UPDATE ScheduledJob
SET ScheduledJobTriggerID = NULL
WHERE ScheduledJobTriggerID IN ( SELECT FO_ScheduledJobTriggerID FROM ScheduledJobTrigger_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER ScheduledJob_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in ScheduledJob_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(ScheduledJob.ScheduledJobID),0) FROM ScheduledJob)
UPDATE ScheduledJob_Recovery
SET ScheduledJob_Recovery.FO_ScheduledJobID = ScheduledJob_Recovery.ScheduledJobID + @max1
FROM ScheduledJob_Recovery
WHERE ScheduledJob_Recovery.FO_ScheduledJobID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeploymentJob */ 
UPDATE r
SET r.ScheduledJobID = ISNULL(fo.FO_ScheduledJobID, r.ScheduledJobID), 
r.FO_MergeCode = CASE WHEN fo.ScheduledJobID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeploymentJob_Recovery r
LEFT OUTER JOIN ScheduledJob_Recovery AS fo ON r.ScheduledJobID = fo.ScheduledJobID
WHERE r.ScheduledJobID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ScheduledJobRun */ 
UPDATE r
SET r.ScheduledJobID = ISNULL(fo.FO_ScheduledJobID, r.ScheduledJobID), 
r.FO_MergeCode = CASE WHEN fo.ScheduledJobID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ScheduledJobRun_Recovery r
LEFT OUTER JOIN ScheduledJob_Recovery AS fo ON r.ScheduledJobID = fo.ScheduledJobID
WHERE r.ScheduledJobID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ScheduledJobTarget */ 
UPDATE r
SET r.ScheduledJobID = ISNULL(fo.FO_ScheduledJobID, r.ScheduledJobID), 
r.FO_MergeCode = CASE WHEN fo.ScheduledJobID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ScheduledJobTarget_Recovery r
LEFT OUTER JOIN ScheduledJob_Recovery AS fo ON r.ScheduledJobID = fo.ScheduledJobID
WHERE r.ScheduledJobID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER DeploymentJob_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in DeploymentJob_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(DeploymentJob.DeploymentJobID),0) FROM DeploymentJob)
UPDATE DeploymentJob_Recovery
SET DeploymentJob_Recovery.FO_DeploymentJobID = DeploymentJob_Recovery.DeploymentJobID + @max1
FROM DeploymentJob_Recovery
WHERE DeploymentJob_Recovery.FO_DeploymentJobID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeploymentJobComponents */ 
UPDATE r
SET r.DeploymentJobID = ISNULL(fo.FO_DeploymentJobID, r.DeploymentJobID), 
r.FO_MergeCode = CASE WHEN fo.DeploymentJobID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeploymentJobComponents_Recovery r
LEFT OUTER JOIN DeploymentJob_Recovery AS fo ON r.DeploymentJobID = fo.DeploymentJobID
WHERE r.DeploymentJobID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeploymentJobGroups */ 
UPDATE r
SET r.DeploymentJobID = ISNULL(fo.FO_DeploymentJobID, r.DeploymentJobID), 
r.FO_MergeCode = CASE WHEN fo.DeploymentJobID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeploymentJobGroups_Recovery r
LEFT OUTER JOIN DeploymentJob_Recovery AS fo ON r.DeploymentJobID = fo.DeploymentJobID
WHERE r.DeploymentJobID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeploymentJobPolicyVersions */ 
UPDATE r
SET r.DeploymentJobID = ISNULL(fo.FO_DeploymentJobID, r.DeploymentJobID), 
r.FO_MergeCode = CASE WHEN fo.DeploymentJobID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeploymentJobPolicyVersions_Recovery r
LEFT OUTER JOIN DeploymentJob_Recovery AS fo ON r.DeploymentJobID = fo.DeploymentJobID
WHERE r.DeploymentJobID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER ScheduledJobRun_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in ScheduledJobRun_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(ScheduledJobRun.ScheduledJobRunID),0) FROM ScheduledJobRun)
UPDATE ScheduledJobRun_Recovery
SET ScheduledJobRun_Recovery.FO_ScheduledJobRunID = ScheduledJobRun_Recovery.ScheduledJobRunID + @max1
FROM ScheduledJobRun_Recovery
WHERE ScheduledJobRun_Recovery.FO_ScheduledJobRunID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ScheduledJobTrigger */ 
UPDATE r
SET r.NextScheduledJobRunID = ISNULL(fo.FO_ScheduledJobRunID, r.NextScheduledJobRunID), 
r.FO_MergeCode = CASE WHEN fo.ScheduledJobRunID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ScheduledJobTrigger_Recovery r
LEFT OUTER JOIN ScheduledJobRun_Recovery AS fo ON r.NextScheduledJobRunID = fo.ScheduledJobRunID
WHERE r.NextScheduledJobRunID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out NextScheduledJobRunID for deleted FO_ScheduledJobRunID */ 
UPDATE ScheduledJobTrigger
SET NextScheduledJobRunID = NULL
WHERE NextScheduledJobRunID IN ( SELECT FO_ScheduledJobRunID FROM ScheduledJobRun_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber ScheduledJobTrigger */ 
UPDATE r
SET r.LastScheduledJobRunID = ISNULL(fo.FO_ScheduledJobRunID, r.LastScheduledJobRunID), 
r.FO_MergeCode = CASE WHEN fo.ScheduledJobRunID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ScheduledJobTrigger_Recovery r
LEFT OUTER JOIN ScheduledJobRun_Recovery AS fo ON r.LastScheduledJobRunID = fo.ScheduledJobRunID
WHERE r.LastScheduledJobRunID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out LastScheduledJobRunID for deleted FO_ScheduledJobRunID */ 
UPDATE ScheduledJobTrigger
SET LastScheduledJobRunID = NULL
WHERE LastScheduledJobRunID IN ( SELECT FO_ScheduledJobRunID FROM ScheduledJobRun_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER ScheduledJobTarget_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in ScheduledJobTarget_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(ScheduledJobTarget.ScheduledJobTargetID),0) FROM ScheduledJobTarget)
UPDATE ScheduledJobTarget_Recovery
SET ScheduledJobTarget_Recovery.FO_ScheduledJobTargetID = ScheduledJobTarget_Recovery.ScheduledJobTargetID + @max1
FROM ScheduledJobTarget_Recovery
WHERE ScheduledJobTarget_Recovery.FO_ScheduledJobTargetID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER SiteFilters_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in SiteFilters_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(SiteFilters.SiteFilterID),0) FROM SiteFilters)
UPDATE SiteFilters_Recovery
SET SiteFilters_Recovery.FO_SiteFilterID = SiteFilters_Recovery.SiteFilterID + @max1
FROM SiteFilters_Recovery
WHERE SiteFilters_Recovery.FO_SiteFilterID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber SiteFilterRules */ 
UPDATE r
SET r.SiteFilterID = ISNULL(fo.FO_SiteFilterID, r.SiteFilterID), 
r.FO_MergeCode = CASE WHEN fo.SiteFilterID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM SiteFilterRules_Recovery r
LEFT OUTER JOIN SiteFilters_Recovery AS fo ON r.SiteFilterID = fo.SiteFilterID
WHERE r.SiteFilterID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER SiteFilterRules_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in SiteFilterRules_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(SiteFilterRules.SiteFilterRuleID),0) FROM SiteFilterRules)
UPDATE SiteFilterRules_Recovery
SET SiteFilterRules_Recovery.FO_SiteFilterRuleID = SiteFilterRules_Recovery.SiteFilterRuleID + @max1
FROM SiteFilterRules_Recovery
WHERE SiteFilterRules_Recovery.FO_SiteFilterRuleID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER SiteRange_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE SiteRange_Recovery
SET SiteRange_Recovery.FO_MergeCode = CASE WHEN SiteRange_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE SiteRange_Recovery.FO_MergeCode END, 
	SiteRange_Recovery.FO_SiteRangeID = SiteRange.SiteRangeID
FROM SiteRange_Recovery
INNER JOIN SiteRange ON 	(((SiteRange_Recovery.StartIPNbr = SiteRange.StartIPNbr) OR (SiteRange_Recovery.StartIPNbr IS NULL AND SiteRange.StartIPNbr IS NULL)) AND 
		((SiteRange_Recovery.EndIPNbr = SiteRange.EndIPNbr) OR (SiteRange_Recovery.EndIPNbr IS NULL AND SiteRange.EndIPNbr IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(SiteRange.SiteRangeID),0) FROM SiteRange)
UPDATE SiteRange_Recovery
SET SiteRange_Recovery.FO_SiteRangeID = SiteRange_Recovery.SiteRangeID + @max1
FROM SiteRange_Recovery
WHERE SiteRange_Recovery.FO_SiteRangeID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER Sites_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in Sites_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Sites.SiteID),0) FROM Sites)
UPDATE Sites_Recovery
SET Sites_Recovery.FO_SiteID = Sites_Recovery.SiteID + @max1
FROM Sites_Recovery
WHERE Sites_Recovery.FO_SiteID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Groups */ 
UPDATE r
SET r.SiteID = ISNULL(fo.FO_SiteID, r.SiteID), 
r.FO_MergeCode = CASE WHEN fo.SiteID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Groups_Recovery r
LEFT OUTER JOIN Sites_Recovery AS fo ON r.SiteID = fo.SiteID
WHERE r.SiteID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out SiteID for deleted FO_SiteID */ 
UPDATE Groups
SET SiteID = NULL
WHERE SiteID IN ( SELECT FO_SiteID FROM Sites_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER Groups_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in Groups_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Groups.GroupID),0) FROM Groups)
UPDATE Groups_Recovery
SET Groups_Recovery.FO_GroupID = Groups_Recovery.GroupID + @max1
FROM Groups_Recovery
WHERE Groups_Recovery.FO_GroupID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ActionDetails */ 
UPDATE r
SET r.ComponentGroupID = ISNULL(fo.FO_GroupID, r.ComponentGroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ActionDetails_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.ComponentGroupID = fo.GroupID
WHERE r.ComponentGroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ComponentGroupID for deleted FO_GroupID */ 
UPDATE ActionDetails
SET ComponentGroupID = NULL
WHERE ComponentGroupID IN ( SELECT FO_GroupID FROM Groups_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber Component */ 
UPDATE r
SET r.PolicyGroupID = ISNULL(fo.FO_GroupID, r.PolicyGroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Component_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.PolicyGroupID = fo.GroupID
WHERE r.PolicyGroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out PolicyGroupID for deleted FO_GroupID */ 
UPDATE Component
SET PolicyGroupID = NULL
WHERE PolicyGroupID IN ( SELECT FO_GroupID FROM Groups_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeployedPolicy */ 
UPDATE r
SET r.GroupID = ISNULL(fo.FO_GroupID, r.GroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeployedPolicy_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.GroupID = fo.GroupID
WHERE r.GroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out GroupID for deleted FO_GroupID */ 
UPDATE DeployedPolicy
SET GroupID = NULL
WHERE GroupID IN ( SELECT FO_GroupID FROM Groups_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeploymentJobGroups */ 
UPDATE r
SET r.GroupID = ISNULL(fo.FO_GroupID, r.GroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeploymentJobGroups_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.GroupID = fo.GroupID
WHERE r.GroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DocumentReceipt */ 
UPDATE r
SET r.GroupID = ISNULL(fo.FO_GroupID, r.GroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DocumentReceipt_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.GroupID = fo.GroupID
WHERE r.GroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out GroupID for deleted FO_GroupID */ 
UPDATE DocumentReceipt
SET GroupID = NULL
WHERE GroupID IN ( SELECT FO_GroupID FROM Groups_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber GroupHostLinks */ 
UPDATE r
SET r.GroupID = ISNULL(fo.FO_GroupID, r.GroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM GroupHostLinks_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.GroupID = fo.GroupID
WHERE r.GroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber GroupPolicy */ 
UPDATE r
SET r.GroupID = ISNULL(fo.FO_GroupID, r.GroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM GroupPolicy_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.GroupID = fo.GroupID
WHERE r.GroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber Groups */ 
UPDATE r
SET r.ParentGroupID = ISNULL(fo.FO_GroupID, r.ParentGroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Groups_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.ParentGroupID = fo.GroupID
WHERE r.ParentGroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ParentGroupID for deleted FO_GroupID */ 
UPDATE Groups
SET ParentGroupID = NULL
WHERE ParentGroupID IN ( SELECT FO_GroupID FROM Groups_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber Repository */ 
UPDATE r
SET r.GroupID = ISNULL(fo.FO_GroupID, r.GroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Repository_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.GroupID = fo.GroupID
WHERE r.GroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber SubTask */ 
UPDATE r
SET r.GroupID = ISNULL(fo.FO_GroupID, r.GroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM SubTask_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.GroupID = fo.GroupID
WHERE r.GroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out GroupID for deleted FO_GroupID */ 
UPDATE SubTask
SET GroupID = NULL
WHERE GroupID IN ( SELECT FO_GroupID FROM Groups_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber Task */ 
UPDATE r
SET r.GroupID = ISNULL(fo.FO_GroupID, r.GroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Task_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.GroupID = fo.GroupID
WHERE r.GroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out GroupID for deleted FO_GroupID */ 
UPDATE Task
SET GroupID = NULL
WHERE GroupID IN ( SELECT FO_GroupID FROM Groups_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber TicketRule */ 
UPDATE r
SET r.GroupID = ISNULL(fo.FO_GroupID, r.GroupID), 
r.FO_MergeCode = CASE WHEN fo.GroupID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM TicketRule_Recovery r
LEFT OUTER JOIN Groups_Recovery AS fo ON r.GroupID = fo.GroupID
WHERE r.GroupID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER Component_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in Component_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Component.ComponentID),0) FROM Component)
UPDATE Component_Recovery
SET Component_Recovery.FO_ComponentID = Component_Recovery.ComponentID + @max1
FROM Component_Recovery
WHERE Component_Recovery.FO_ComponentID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ActionDetails */ 
UPDATE r
SET r.ComponentID = ISNULL(fo.FO_ComponentID, r.ComponentID), 
r.FO_MergeCode = CASE WHEN fo.ComponentID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ActionDetails_Recovery r
LEFT OUTER JOIN Component_Recovery AS fo ON r.ComponentID = fo.ComponentID
WHERE r.ComponentID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ComponentID for deleted FO_ComponentID */ 
UPDATE ActionDetails
SET ComponentID = NULL
WHERE ComponentID IN ( SELECT FO_ComponentID FROM Component_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber ActionDetails */ 
UPDATE r
SET r.ControllerID = ISNULL(fo.FO_ComponentID, r.ControllerID), 
r.FO_MergeCode = CASE WHEN fo.ComponentID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ActionDetails_Recovery r
LEFT OUTER JOIN Component_Recovery AS fo ON r.ControllerID = fo.ComponentID
WHERE r.ControllerID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ControllerID for deleted FO_ComponentID */ 
UPDATE ActionDetails
SET ControllerID = NULL
WHERE ControllerID IN ( SELECT FO_ComponentID FROM Component_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber ActionJob */ 
UPDATE r
SET r.ComponentID = ISNULL(fo.FO_ComponentID, r.ComponentID), 
r.FO_MergeCode = CASE WHEN fo.ComponentID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ActionJob_Recovery r
LEFT OUTER JOIN Component_Recovery AS fo ON r.ComponentID = fo.ComponentID
WHERE r.ComponentID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ComponentID for deleted FO_ComponentID */ 
UPDATE ActionJob
SET ComponentID = NULL
WHERE ComponentID IN ( SELECT FO_ComponentID FROM Component_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber Component */ 
UPDATE r
SET r.EventCollectorID = ISNULL(fo.FO_ComponentID, r.EventCollectorID), 
r.FO_MergeCode = CASE WHEN fo.ComponentID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM Component_Recovery r
LEFT OUTER JOIN Component_Recovery AS fo ON r.EventCollectorID = fo.ComponentID
WHERE r.EventCollectorID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out EventCollectorID for deleted FO_ComponentID */ 
UPDATE Component
SET EventCollectorID = NULL
WHERE EventCollectorID IN ( SELECT FO_ComponentID FROM Component_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber ComponentSubscription */ 
UPDATE r
SET r.ComponentID = ISNULL(fo.FO_ComponentID, r.ComponentID), 
r.FO_MergeCode = CASE WHEN fo.ComponentID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ComponentSubscription_Recovery r
LEFT OUTER JOIN Component_Recovery AS fo ON r.ComponentID = fo.ComponentID
WHERE r.ComponentID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeployedPolicy */ 
UPDATE r
SET r.ComponentID = ISNULL(fo.FO_ComponentID, r.ComponentID), 
r.FO_MergeCode = CASE WHEN fo.ComponentID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeployedPolicy_Recovery r
LEFT OUTER JOIN Component_Recovery AS fo ON r.ComponentID = fo.ComponentID
WHERE r.ComponentID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out ComponentID for deleted FO_ComponentID */ 
UPDATE DeployedPolicy
SET ComponentID = NULL
WHERE ComponentID IN ( SELECT FO_ComponentID FROM Component_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeploymentJobComponents */ 
UPDATE r
SET r.ComponentID = ISNULL(fo.FO_ComponentID, r.ComponentID), 
r.FO_MergeCode = CASE WHEN fo.ComponentID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeploymentJobComponents_Recovery r
LEFT OUTER JOIN Component_Recovery AS fo ON r.ComponentID = fo.ComponentID
WHERE r.ComponentID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DocumentReceipt */ 
UPDATE r
SET r.ComponentID = ISNULL(fo.FO_ComponentID, r.ComponentID), 
r.FO_MergeCode = CASE WHEN fo.ComponentID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DocumentReceipt_Recovery r
LEFT OUTER JOIN Component_Recovery AS fo ON r.ComponentID = fo.ComponentID
WHERE r.ComponentID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber PolicySandbox */ 
UPDATE r
SET r.ComponentID = ISNULL(fo.FO_ComponentID, r.ComponentID), 
r.FO_MergeCode = CASE WHEN fo.ComponentID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM PolicySandbox_Recovery r
LEFT OUTER JOIN Component_Recovery AS fo ON r.ComponentID = fo.ComponentID
WHERE r.ComponentID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber SubTask */ 
UPDATE r
SET r.AssignedComponentID = ISNULL(fo.FO_ComponentID, r.AssignedComponentID), 
r.FO_MergeCode = CASE WHEN fo.ComponentID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM SubTask_Recovery r
LEFT OUTER JOIN Component_Recovery AS fo ON r.AssignedComponentID = fo.ComponentID
WHERE r.AssignedComponentID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out AssignedComponentID for deleted FO_ComponentID */ 
UPDATE SubTask
SET AssignedComponentID = NULL
WHERE AssignedComponentID IN ( SELECT FO_ComponentID FROM Component_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER ActionDetails_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in ActionDetails_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(ActionDetails.ActionDetailsID),0) FROM ActionDetails)
UPDATE ActionDetails_Recovery
SET ActionDetails_Recovery.FO_ActionDetailsID = ActionDetails_Recovery.ActionDetailsID + @max1
FROM ActionDetails_Recovery
WHERE ActionDetails_Recovery.FO_ActionDetailsID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ActionJob */ 
UPDATE r
SET r.ActionDetailsID = ISNULL(fo.FO_ActionDetailsID, r.ActionDetailsID), 
r.FO_MergeCode = CASE WHEN fo.ActionDetailsID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ActionJob_Recovery r
LEFT OUTER JOIN ActionDetails_Recovery AS fo ON r.ActionDetailsID = fo.ActionDetailsID
WHERE r.ActionDetailsID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER ActionJob_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in ActionJob_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(ActionJob.ActionJobID),0) FROM ActionJob)
UPDATE ActionJob_Recovery
SET ActionJob_Recovery.FO_ActionJobID = ActionJob_Recovery.ActionJobID + @max1
FROM ActionJob_Recovery
WHERE ActionJob_Recovery.FO_ActionJobID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber ReportInstance */ 
UPDATE r
SET r.ReportInstanceID = ISNULL(fo.FO_ActionJobID, r.ReportInstanceID), 
r.FO_MergeCode = CASE WHEN fo.ActionJobID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM ReportInstance_Recovery r
LEFT OUTER JOIN ActionJob_Recovery AS fo ON r.ReportInstanceID = fo.ActionJobID
WHERE r.ReportInstanceID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER ComponentSubscription_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in ComponentSubscription_Recovery */
/********************************************************************************** 
 *                     RENUMBER DeploymentJobComponents_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in DeploymentJobComponents_Recovery */
/********************************************************************************** 
 *                     RENUMBER DeploymentJobGroups_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in DeploymentJobGroups_Recovery */
/********************************************************************************** 
 *                     RENUMBER GroupHostLinks_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in GroupHostLinks_Recovery */
/********************************************************************************** 
 *                     RENUMBER GroupPolicy_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in GroupPolicy_Recovery */
/********************************************************************************** 
 *                     RENUMBER PolicySandbox_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in PolicySandbox_Recovery */
/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(PolicySandbox.PolicySandboxID),0) FROM PolicySandbox)
UPDATE PolicySandbox_Recovery
SET PolicySandbox_Recovery.FO_PolicySandboxID = PolicySandbox_Recovery.PolicySandboxID + @max1
FROM PolicySandbox_Recovery
WHERE PolicySandbox_Recovery.FO_PolicySandboxID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DocumentReceipt */ 
UPDATE r
SET r.PolicySandboxID = ISNULL(fo.FO_PolicySandboxID, r.PolicySandboxID), 
r.FO_MergeCode = CASE WHEN fo.PolicySandboxID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DocumentReceipt_Recovery r
LEFT OUTER JOIN PolicySandbox_Recovery AS fo ON r.PolicySandboxID = fo.PolicySandboxID
WHERE r.PolicySandboxID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out PolicySandboxID for deleted FO_PolicySandboxID */ 
UPDATE DocumentReceipt
SET PolicySandboxID = NULL
WHERE PolicySandboxID IN ( SELECT FO_PolicySandboxID FROM PolicySandbox_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER ReportInstance_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in ReportInstance_Recovery */
/********************************************************************************** 
 *                     RENUMBER Repository_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE Repository_Recovery
SET Repository_Recovery.FO_MergeCode = CASE WHEN Repository_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE Repository_Recovery.FO_MergeCode END, 
	Repository_Recovery.FO_RepositoryID = Repository.RepositoryID
FROM Repository_Recovery
INNER JOIN Repository ON 	(((Repository_Recovery.GroupID = Repository.GroupID) OR (Repository_Recovery.GroupID IS NULL AND Repository.GroupID IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Repository.RepositoryID),0) FROM Repository)
UPDATE Repository_Recovery
SET Repository_Recovery.FO_RepositoryID = Repository_Recovery.RepositoryID + @max1
FROM Repository_Recovery
WHERE Repository_Recovery.FO_RepositoryID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber GlobalObject */ 
UPDATE r
SET r.RepositoryID = ISNULL(fo.FO_RepositoryID, r.RepositoryID), 
r.FO_MergeCode = CASE WHEN fo.RepositoryID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM GlobalObject_Recovery r
LEFT OUTER JOIN Repository_Recovery AS fo ON r.RepositoryID = fo.RepositoryID
WHERE r.RepositoryID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out RepositoryID for deleted FO_RepositoryID */ 
UPDATE GlobalObject
SET RepositoryID = NULL
WHERE RepositoryID IN ( SELECT FO_RepositoryID FROM Repository_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/* Renumber PolicyRepository */ 
UPDATE r
SET r.RepositoryID = ISNULL(fo.FO_RepositoryID, r.RepositoryID), 
r.FO_MergeCode = CASE WHEN fo.RepositoryID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM PolicyRepository_Recovery r
LEFT OUTER JOIN Repository_Recovery AS fo ON r.RepositoryID = fo.RepositoryID
WHERE r.RepositoryID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER GlobalObject_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE GlobalObject_Recovery
SET GlobalObject_Recovery.FO_MergeCode = CASE WHEN GlobalObject_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE GlobalObject_Recovery.FO_MergeCode END, 
	GlobalObject_Recovery.FO_GlobalObjectID = GlobalObject.GlobalObjectID
FROM GlobalObject_Recovery
INNER JOIN GlobalObject ON 	(((GlobalObject_Recovery.NamespaceID = GlobalObject.NamespaceID) OR (GlobalObject_Recovery.NamespaceID IS NULL AND GlobalObject.NamespaceID IS NULL)) AND 
		((GlobalObject_Recovery.SchemaVersion = GlobalObject.SchemaVersion) OR (GlobalObject_Recovery.SchemaVersion IS NULL AND GlobalObject.SchemaVersion IS NULL)) AND 
		((GlobalObject_Recovery.RepositoryID = GlobalObject.RepositoryID) OR (GlobalObject_Recovery.RepositoryID IS NULL AND GlobalObject.RepositoryID IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(GlobalObject.GlobalObjectID),0) FROM GlobalObject)
UPDATE GlobalObject_Recovery
SET GlobalObject_Recovery.FO_GlobalObjectID = GlobalObject_Recovery.GlobalObjectID + @max1
FROM GlobalObject_Recovery
WHERE GlobalObject_Recovery.FO_GlobalObjectID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DocumentReceipt */ 
UPDATE r
SET r.GlobalObjectID = ISNULL(fo.FO_GlobalObjectID, r.GlobalObjectID), 
r.FO_MergeCode = CASE WHEN fo.GlobalObjectID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DocumentReceipt_Recovery r
LEFT OUTER JOIN GlobalObject_Recovery AS fo ON r.GlobalObjectID = fo.GlobalObjectID
WHERE r.GlobalObjectID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out GlobalObjectID for deleted FO_GlobalObjectID */ 
UPDATE DocumentReceipt
SET GlobalObjectID = NULL
WHERE GlobalObjectID IN ( SELECT FO_GlobalObjectID FROM GlobalObject_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER PolicyRepository_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE PolicyRepository_Recovery
SET PolicyRepository_Recovery.FO_MergeCode = CASE WHEN PolicyRepository_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE PolicyRepository_Recovery.FO_MergeCode END, 
	PolicyRepository_Recovery.FO_PolicyRepositoryID = PolicyRepository.PolicyRepositoryID
FROM PolicyRepository_Recovery
INNER JOIN PolicyRepository ON 	(((PolicyRepository_Recovery.Name = PolicyRepository.Name) OR (PolicyRepository_Recovery.Name IS NULL AND PolicyRepository.Name IS NULL)) AND 
		((PolicyRepository_Recovery.NamespaceID = PolicyRepository.NamespaceID) OR (PolicyRepository_Recovery.NamespaceID IS NULL AND PolicyRepository.NamespaceID IS NULL)) AND 
		((PolicyRepository_Recovery.SchemaVersion = PolicyRepository.SchemaVersion) OR (PolicyRepository_Recovery.SchemaVersion IS NULL AND PolicyRepository.SchemaVersion IS NULL)) AND 
		((PolicyRepository_Recovery.RepositoryID = PolicyRepository.RepositoryID) OR (PolicyRepository_Recovery.RepositoryID IS NULL AND PolicyRepository.RepositoryID IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(PolicyRepository.PolicyRepositoryID),0) FROM PolicyRepository)
UPDATE PolicyRepository_Recovery
SET PolicyRepository_Recovery.FO_PolicyRepositoryID = PolicyRepository_Recovery.PolicyRepositoryID + @max1
FROM PolicyRepository_Recovery
WHERE PolicyRepository_Recovery.FO_PolicyRepositoryID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber PolicyRepositoryVersion */ 
UPDATE r
SET r.PolicyRepositoryID = ISNULL(fo.FO_PolicyRepositoryID, r.PolicyRepositoryID), 
r.FO_MergeCode = CASE WHEN fo.PolicyRepositoryID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM PolicyRepositoryVersion_Recovery r
LEFT OUTER JOIN PolicyRepository_Recovery AS fo ON r.PolicyRepositoryID = fo.PolicyRepositoryID
WHERE r.PolicyRepositoryID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER PolicyRepositoryVersion_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE PolicyRepositoryVersion_Recovery
SET PolicyRepositoryVersion_Recovery.FO_MergeCode = CASE WHEN PolicyRepositoryVersion_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE PolicyRepositoryVersion_Recovery.FO_MergeCode END, 
	PolicyRepositoryVersion_Recovery.FO_PolicyRepositoryVersionID = PolicyRepositoryVersion.PolicyRepositoryVersionID
FROM PolicyRepositoryVersion_Recovery
INNER JOIN PolicyRepositoryVersion ON 	(((PolicyRepositoryVersion_Recovery.Version = PolicyRepositoryVersion.Version) OR (PolicyRepositoryVersion_Recovery.Version IS NULL AND PolicyRepositoryVersion.Version IS NULL)) AND 
		((PolicyRepositoryVersion_Recovery.PolicyRepositoryID = PolicyRepositoryVersion.PolicyRepositoryID) OR (PolicyRepositoryVersion_Recovery.PolicyRepositoryID IS NULL AND PolicyRepositoryVersion.PolicyRepositoryID IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(PolicyRepositoryVersion.PolicyRepositoryVersionID),0) FROM PolicyRepositoryVersion)
UPDATE PolicyRepositoryVersion_Recovery
SET PolicyRepositoryVersion_Recovery.FO_PolicyRepositoryVersionID = PolicyRepositoryVersion_Recovery.PolicyRepositoryVersionID + @max1
FROM PolicyRepositoryVersion_Recovery
WHERE PolicyRepositoryVersion_Recovery.FO_PolicyRepositoryVersionID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeployedPolicy */ 
UPDATE r
SET r.PolicyRepositoryVersionID = ISNULL(fo.FO_PolicyRepositoryVersionID, r.PolicyRepositoryVersionID), 
r.FO_MergeCode = CASE WHEN fo.PolicyRepositoryVersionID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeployedPolicy_Recovery r
LEFT OUTER JOIN PolicyRepositoryVersion_Recovery AS fo ON r.PolicyRepositoryVersionID = fo.PolicyRepositoryVersionID
WHERE r.PolicyRepositoryVersionID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DeploymentJobPolicyVersions */ 
UPDATE r
SET r.PolicyRepositoryVersionID = ISNULL(fo.FO_PolicyRepositoryVersionID, r.PolicyRepositoryVersionID), 
r.FO_MergeCode = CASE WHEN fo.PolicyRepositoryVersionID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DeploymentJobPolicyVersions_Recovery r
LEFT OUTER JOIN PolicyRepositoryVersion_Recovery AS fo ON r.PolicyRepositoryVersionID = fo.PolicyRepositoryVersionID
WHERE r.PolicyRepositoryVersionID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber DocumentReceipt */ 
UPDATE r
SET r.PolicyRepositoryVersionID = ISNULL(fo.FO_PolicyRepositoryVersionID, r.PolicyRepositoryVersionID), 
r.FO_MergeCode = CASE WHEN fo.PolicyRepositoryVersionID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM DocumentReceipt_Recovery r
LEFT OUTER JOIN PolicyRepositoryVersion_Recovery AS fo ON r.PolicyRepositoryVersionID = fo.PolicyRepositoryVersionID
WHERE r.PolicyRepositoryVersionID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out PolicyRepositoryVersionID for deleted FO_PolicyRepositoryVersionID */ 
UPDATE DocumentReceipt
SET PolicyRepositoryVersionID = NULL
WHERE PolicyRepositoryVersionID IN ( SELECT FO_PolicyRepositoryVersionID FROM PolicyRepositoryVersion_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER DeployedPolicy_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE DeployedPolicy_Recovery
SET DeployedPolicy_Recovery.FO_MergeCode = CASE WHEN DeployedPolicy_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE DeployedPolicy_Recovery.FO_MergeCode END, 
	DeployedPolicy_Recovery.FO_DeployedPolicyID = DeployedPolicy.DeployedPolicyID
FROM DeployedPolicy_Recovery
INNER JOIN DeployedPolicy ON 	(((DeployedPolicy_Recovery.GroupID = DeployedPolicy.GroupID) OR (DeployedPolicy_Recovery.GroupID IS NULL AND DeployedPolicy.GroupID IS NULL)) AND 
		((DeployedPolicy_Recovery.ComponentID = DeployedPolicy.ComponentID) OR (DeployedPolicy_Recovery.ComponentID IS NULL AND DeployedPolicy.ComponentID IS NULL)) AND 
		((DeployedPolicy_Recovery.NamespaceID = DeployedPolicy.NamespaceID) OR (DeployedPolicy_Recovery.NamespaceID IS NULL AND DeployedPolicy.NamespaceID IS NULL)) AND 
		((DeployedPolicy_Recovery.SchemaVersion = DeployedPolicy.SchemaVersion) OR (DeployedPolicy_Recovery.SchemaVersion IS NULL AND DeployedPolicy.SchemaVersion IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(DeployedPolicy.DeployedPolicyID),0) FROM DeployedPolicy)
UPDATE DeployedPolicy_Recovery
SET DeployedPolicy_Recovery.FO_DeployedPolicyID = DeployedPolicy_Recovery.DeployedPolicyID + @max1
FROM DeployedPolicy_Recovery
WHERE DeployedPolicy_Recovery.FO_DeployedPolicyID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER DeploymentJobPolicyVersions_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in DeploymentJobPolicyVersions_Recovery */
/********************************************************************************** 
 *                     RENUMBER DocumentReceipt_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in DocumentReceipt_Recovery */
/********************************************************************************** 
 *                     RENUMBER SPUserGroup_Recovery
 **********************************************************************************/
/*
 * There is no identity to renumber in SPUserGroup
 */

/* Renumber SPUserGroupMember */ 
UPDATE r
SET r.SPUserGroupPrincipalID = ISNULL(fo.PrincipalID, r.SPUserGroupPrincipalID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM SPUserGroupMember_Recovery r
LEFT OUTER JOIN SPUserGroup_Recovery AS fo ON r.SPUserGroupPrincipalID = fo.PrincipalID
WHERE r.SPUserGroupPrincipalID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER SPUserGroupMember_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE SPUserGroupMember_Recovery
SET SPUserGroupMember_Recovery.FO_MergeCode = CASE WHEN SPUserGroupMember_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE SPUserGroupMember_Recovery.FO_MergeCode END, 
	SPUserGroupMember_Recovery.FO_SPUserGroupMemberID = SPUserGroupMember.SPUserGroupMemberID
FROM SPUserGroupMember_Recovery
INNER JOIN SPUserGroupMember ON 	(((SPUserGroupMember_Recovery.PrincipalID = SPUserGroupMember.PrincipalID) OR (SPUserGroupMember_Recovery.PrincipalID IS NULL AND SPUserGroupMember.PrincipalID IS NULL)) AND 
		((SPUserGroupMember_Recovery.SPUserGroupPrincipalID = SPUserGroupMember.SPUserGroupPrincipalID) OR (SPUserGroupMember_Recovery.SPUserGroupPrincipalID IS NULL AND SPUserGroupMember.SPUserGroupPrincipalID IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(SPUserGroupMember.SPUserGroupMemberID),0) FROM SPUserGroupMember)
UPDATE SPUserGroupMember_Recovery
SET SPUserGroupMember_Recovery.FO_SPUserGroupMemberID = SPUserGroupMember_Recovery.SPUserGroupMemberID + @max1
FROM SPUserGroupMember_Recovery
WHERE SPUserGroupMember_Recovery.FO_SPUserGroupMemberID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER Task_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE Task_Recovery
SET Task_Recovery.FO_MergeCode = CASE WHEN Task_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE Task_Recovery.FO_MergeCode END, 
	Task_Recovery.FO_TaskID = Task.TaskID
FROM Task_Recovery
INNER JOIN Task ON 	(((Task_Recovery.TaskGUID = Task.TaskGUID) OR (Task_Recovery.TaskGUID IS NULL AND Task.TaskGUID IS NULL)) AND 
		((Task_Recovery.InstanceTimeStamp = Task.InstanceTimeStamp) OR (Task_Recovery.InstanceTimeStamp IS NULL AND Task.InstanceTimeStamp IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(Task.TaskID),0) FROM Task)
UPDATE Task_Recovery
SET Task_Recovery.FO_TaskID = Task_Recovery.TaskID + @max1
FROM Task_Recovery
WHERE Task_Recovery.FO_TaskID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber SubTask */ 
UPDATE r
SET r.TaskID = ISNULL(fo.FO_TaskID, r.TaskID), 
r.FO_MergeCode = CASE WHEN fo.TaskID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM SubTask_Recovery r
LEFT OUTER JOIN Task_Recovery AS fo ON r.TaskID = fo.TaskID
WHERE r.TaskID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER SubTask_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in SubTask_Recovery */
/********************************************************************************** 
 *                     RENUMBER TicketOptions_Recovery
 **********************************************************************************/
/* No unique alternate keys to renumber in TicketOptions_Recovery */
/********************************************************************************** 
 *                     RENUMBER TicketPriority_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE TicketPriority_Recovery
SET TicketPriority_Recovery.FO_MergeCode = CASE WHEN TicketPriority_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE TicketPriority_Recovery.FO_MergeCode END, 
	TicketPriority_Recovery.FO_TicketPriorityID = TicketPriority.TicketPriorityID
FROM TicketPriority_Recovery
INNER JOIN TicketPriority ON 	(((TicketPriority_Recovery.TicketPriorityName = TicketPriority.TicketPriorityName) OR (TicketPriority_Recovery.TicketPriorityName IS NULL AND TicketPriority.TicketPriorityName IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(TicketPriority.TicketPriorityID),0) FROM TicketPriority)
UPDATE TicketPriority_Recovery
SET TicketPriority_Recovery.FO_TicketPriorityID = TicketPriority_Recovery.TicketPriorityID + @max1
FROM TicketPriority_Recovery
WHERE TicketPriority_Recovery.FO_TicketPriorityID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/* Renumber TicketRule */ 
UPDATE r
SET r.TicketPriorityID = ISNULL(fo.FO_TicketPriorityID, r.TicketPriorityID), 
r.FO_MergeCode = CASE WHEN fo.TicketPriorityID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM TicketRule_Recovery r
LEFT OUTER JOIN TicketPriority_Recovery AS fo ON r.TicketPriorityID = fo.TicketPriorityID
WHERE r.TicketPriorityID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out TicketPriorityID for deleted FO_TicketPriorityID */ 
UPDATE TicketRule
SET TicketPriorityID = NULL
WHERE TicketPriorityID IN ( SELECT FO_TicketPriorityID FROM TicketPriority_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER TicketProvider_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE TicketProvider_Recovery
SET TicketProvider_Recovery.FO_MergeCode = CASE WHEN TicketProvider_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE TicketProvider_Recovery.FO_MergeCode END, 
	TicketProvider_Recovery.FO_ProviderID = TicketProvider.ProviderID
FROM TicketProvider_Recovery
INNER JOIN TicketProvider ON 	(((TicketProvider_Recovery.ProviderName = TicketProvider.ProviderName) OR (TicketProvider_Recovery.ProviderName IS NULL AND TicketProvider.ProviderName IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(TicketProvider.ProviderID),0) FROM TicketProvider)
UPDATE TicketProvider_Recovery
SET TicketProvider_Recovery.FO_ProviderID = TicketProvider_Recovery.ProviderID + @max1
FROM TicketProvider_Recovery
WHERE TicketProvider_Recovery.FO_ProviderID IS NULL 

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER Users_Recovery
 **********************************************************************************/
/*
 * There is no identity to renumber in Users
 */

/* Renumber TicketRule */ 
UPDATE r
SET r.TicketOwnerID = ISNULL(fo.PrincipalID, r.TicketOwnerID), 
r.FO_MergeCode = CASE WHEN fo.PrincipalID IS NULL THEN 'X' ELSE r.FO_MergeCode END 
FROM TicketRule_Recovery r
LEFT OUTER JOIN Users_Recovery AS fo ON r.TicketOwnerID = fo.PrincipalID
WHERE r.TicketOwnerID IS NOT NULL 

IF @@ERROR <> 0 RETURN(1)

/* NULL out TicketOwnerID for deleted FO_PrincipalID */ 
UPDATE TicketRule
SET TicketOwnerID = NULL
WHERE TicketOwnerID IN ( SELECT PrincipalID FROM Users_Recovery
		WHERE FO_MergeCode = 'd' )

IF @@ERROR <> 0 RETURN(1)

/********************************************************************************** 
 *                     RENUMBER TicketRule_Recovery
 **********************************************************************************/
/* Renumber records matching unique keys */
UPDATE TicketRule_Recovery
SET TicketRule_Recovery.FO_MergeCode = CASE WHEN TicketRule_Recovery.FO_MergeCode = 'I' THEN 'U' ELSE TicketRule_Recovery.FO_MergeCode END, 
	TicketRule_Recovery.FO_TicketRuleID = TicketRule.TicketRuleID
FROM TicketRule_Recovery
INNER JOIN TicketRule ON 	(((TicketRule_Recovery.GroupID = TicketRule.GroupID) OR (TicketRule_Recovery.GroupID IS NULL AND TicketRule.GroupID IS NULL)) AND 
		((TicketRule_Recovery.RuleName = TicketRule.RuleName) OR (TicketRule_Recovery.RuleName IS NULL AND TicketRule.RuleName IS NULL)))
IF @@ERROR <> 0 RETURN(1)

/* Renumber other records */
SET @max1 = (SELECT ISNULL(MAX(TicketRule.TicketRuleID),0) FROM TicketRule)
UPDATE TicketRule_Recovery
SET TicketRule_Recovery.FO_TicketRuleID = TicketRule_Recovery.TicketRuleID + @max1
FROM TicketRule_Recovery
WHERE TicketRule_Recovery.FO_TicketRuleID IS NULL 

IF @@ERROR <> 0 RETURN(1)


RETURN(0)
GO

