IF OBJECT_ID('iss_Failover_Site_Clear') IS NOT NULL DROP PROCEDURE dbo.iss_Failover_Site_Clear
go
CREATE PROCEDURE dbo.iss_Failover_Site_Clear
AS
/* IBM Confidential - OCO Source Materials */
/* Copyright (c) IBM Corp. 1992, 2007 */
/* Copyright (c) Internet Security Systems, Inc. 1992-2006 */
/* The source code for this program is not published or otherwise divested of its trade secrets, */
/* irrespective of what has been deposited with the U.S. Copyright Office. */ 
DECLARE @SaveErrNbr int, @SaveRowCnt int, @FirstError int, @RetVal int, @ProcName sysname 
SELECT @ProcName = OBJECT_NAME(@@ProcID)
SET NOCOUNT ON
-- iss_error error-number, severity, proc-name, relates-to-errorid, raise-params, errorid (OUT)

DECLARE @Tables TABLE (TableName varchar(8000))

DECLARE @SQLString 		nvarchar(4000),
	@Start			smallint,
	@TableLength 		int,
	@TableList 		varchar(8000),
	@TableClause 		varchar(8000),
	@DeleteTable		varchar(8000),
	@NetworkInterfaceID	int,
	@GroupID		int,
	@RootID			int,
	@RootName		NVARCHAR(160),
	@GroupID_core		int,
	@TableName		sysname,
	@MoveRoot	bit

--Remove all backup tables from prior failovers
DECLARE c_Backup CURSOR LOCAL FOR
SELECT TABLE_NAME
FROM INFORMATION_SCHEMA.tables
WHERE TABLE_NAME LIKE '%_Backup'

OPEN c_Backup
FETCH NEXT FROM c_Backup INTO @TableName

WHILE @@FETCH_STATUS = 0
	BEGIN
	EXEC('DROP TABLE ' + @TableName)
	IF @@ERROR <> 0 RETURN(1)

	FETCH NEXT FROM c_Backup INTO @TableName
	END

CLOSE c_Backup
DEALLOCATE c_Backup

--Create backup Component table. 
IF NOT EXISTS(SELECT 1 FROM sysobjects WHERE Name = 'Component_Backup')
	BEGIN
	SELECT * 
	INTO dbo.Component_Backup 
	FROM Component 
	WHERE RoleID IN (9, 8, 10, 26, 13, 14, 25, 33) 
	AND GUID NOT IN (SELECT GUID FROM Component_Recovery WHERE GUID IS NOT NULL)
	AND Status <> 28
	END

-- Move everything to the root, just like before (excluding a special group)
-- Clear all as before (excluding a special group)
-- Renumber everything, set groupid from root group

SET @RootID = (SELECT GroupID FROM Groups WHERE ParentGroupID IS NULL AND Deleted = 0)
SET @RootName = (SELECT GroupName FROM Groups WHERE GroupID = @RootID)

--Create backup group
IF NOT EXISTS(SELECT 1 FROM Groups WHERE GroupTypeID = 1 AND Deleted = 0)
	BEGIN
	-- Add a group with the same name as the root, directly below the root, with the special GroupType = 1
	EXEC iss_AddGroup @GroupName = @RootName, @GroupDesc = NULL, @GroupViewID = 1, @RoleID = NULL,
		@ParentGroupID = @RootID, @GroupID = @GroupID OUTPUT, @OutGroupViewID = NULL,  @GroupTypeID = 1,
		@ACLID = NULL
	IF @@ERROR <> 0 RETURN(1)

	SET @MoveRoot = 1
	END
ELSE
	BEGIN
	SET @GroupID = (SELECT GroupID FROM Groups WHERE GroupTypeID = 1 AND Deleted = 0)
	IF @@ERROR <> 0 RETURN(1)

	SET @MoveRoot = 0
END

--Create temp table of groups/hosts containing core components, but exclude the root & backup group
SELECT DISTINCT GroupID
INTO #t_OldGroups
FROM GroupHostLinks
WHERE NetworkInterfaceID IN (SELECT NetworkInterfaceID FROM Component_Backup)
AND GroupID <> @GroupID
IF @@ERROR <> 0 RETURN(1)

--Move core components which are not already in the root/secondary group up to root group
INSERT INTO GroupHostLinks(GroupID, NetworkInterfaceID)
SELECT DISTINCT @RootID, NetworkInterfaceID
FROM Component_Backup
WHERE NetworkInterfaceID NOT IN (SELECT NetworkInterfaceID
	FROM GroupHostLinks
	WHERE GroupID = @RootID)
IF @@ERROR <> 0 RETURN(1)

--Move policies from old group to root group
--First, delete root policies to be replaced with policies from old group
DELETE DeployedPolicy
WHERE	GroupID = @RootID
AND  EXISTS (SELECT 1 FROM DeployedPolicy dp2
		WHERE dp2.GroupID IN (SELECT GroupID FROM #t_OldGroups)
		AND   dp2.SchemaVersion = DeployedPolicy.SchemaVersion
		AND   dp2.NameSpaceID = DeployedPolicy.NameSpaceID)
IF @@ERROR <> 0 RETURN(1)

DELETE GroupPolicy
FROM GroupPolicy gp
WHERE GroupID = @RootID
AND EXISTS (SELECT 1 FROM GroupPolicy gp2
		WHERE gp.RoleID = gp2.RoleID
		AND gp2.GroupID IN (SELECT GroupID FROM #t_OldGroups))
IF @@ERROR <> 0 RETURN(1)

--Move policies from old group to root group by updating groupid 
UPDATE DeployedPolicy
SET GroupID = @RootID
WHERE GroupID IN (SELECT GroupID FROM #t_OldGroups)
IF @@ERROR <> 0 RETURN(1)

UPDATE 	GroupPolicy
SET	GroupID = @RootID
WHERE	GroupID IN (SELECT GroupID FROM #t_OldGroups)
IF @@ERROR <> 0 RETURN(1)

--reset policy group of core components
UPDATE 	Component
SET	PolicyGroupID = @RootID
WHERE	PolicyGroupID IN (SELECT GroupID FROM #t_OldGroups)
IF @@ERROR <> 0 RETURN(1)

-- If we just created the secondary backup group, then we need to move the root to the backup group
IF @MoveRoot = 1
	BEGIN
	DECLARE @SQL VARCHAR(8000)
	DECLARE c CURSOR LOCAL FOR
	SELECT 'UPDATE ' + fkc.TABLE_NAME + ' SET ' + fkc.COLUMN_NAME + ' = ' + CAST(@GroupID AS VARCHAR) + ' WHERE ' +
		fkc.COLUMN_NAME + ' = ' + CAST(@RootID AS VARCHAR)
	FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS rc
		INNER JOIN INFORMATION_SCHEMA.TABLE_CONSTRAINTS pk
		ON rc.UNIQUE_CONSTRAINT_NAME = pk.CONSTRAINT_NAME
		INNER JOIN INFORMATION_SCHEMA.TABLE_CONSTRAINTS fk
		ON rc.CONSTRAINT_NAME = fk.CONSTRAINT_NAME
		INNER JOIN INFORMATION_SCHEMA.KEY_COLUMN_USAGE fkc
		ON fk.CONSTRAINT_NAME = fkc.CONSTRAINT_NAME
		INNER JOIN INFORMATION_SCHEMA.KEY_COLUMN_USAGE pkc
		ON pk.CONSTRAINT_NAME = pkc.CONSTRAINT_NAME
	WHERE	pk.TABLE_NAME = 'Groups'
	AND	pk.CONSTRAINT_TYPE = 'PRIMARY KEY'
	AND	fk.TABLE_NAME <> 'Groups' 
	ORDER BY fkc.CONSTRAINT_NAME, fkc.TABLE_NAME

	OPEN c
	FETCH NEXT FROM c INTO @SQL
	
	WHILE @@FETCH_STATUS = 0
		BEGIN
		EXEC(@SQL)
		IF @@ERROR <> 0 RETURN(1)

		FETCH NEXT FROM c INTO @SQL
		END

	CLOSE c
	DEALLOCATE c
	END	
			
--Clear all event data
EXEC @RetVal = iss_TruncateTables

IF @@ERROR <> 0 RETURN(1)

--Remove all data not referenced by core components
Select @TableList = 
'ReportInstance; 
ActionJob WHERE ActionDetailsID IN (SELECT ActionDetailsID FROM ActionDetails WHERE ComponentID NOT IN (SELECT ComponentID FROM Component_Backup) OR (ComponentGroupID IS NOT NULL AND ComponentGroupID <> #Group#));
ActionJob WHERE ActionDetailsID IN (SELECT ActionDetailsID FROM ActionDetails WHERE ControllerID NOT IN (SELECT ComponentID FROM Component_Backup));
ActionDetails WHERE ComponentID NOT IN (SELECT ComponentID FROM Component_Backup) OR (ComponentGroupID IS NOT NULL AND ComponentGroupID <> #Group#);
ActionDetails WHERE ControllerID NOT IN (SELECT ComponentID FROM Component_Backup);
Schedule WHERE ScheduleID NOT IN (SELECT ScheduleID FROM ActionDetails WHERE ScheduleID IS NOT NULL);
DeployedPolicy WHERE ComponentID NOT IN (SELECT ComponentID FROM Component_Backup) OR (GroupID IS NOT NULL AND GroupID <> #Group#);  
GroupHostLinks WHERE NetworkInterfaceID NOT IN (SELECT NetworkInterfaceID FROM Component WHERE ComponentID IN (SELECT ComponentID FROM Component_Backup));
GroupHostLinks WHERE GroupID <> #Group#;
DeploymentJobComponents WHERE ComponentID NOT IN (SELECT ComponentID FROM Component_Backup); 
DocumentReceipt WHERE ComponentID NOT IN (SELECT ComponentID FROM Component_Backup) OR (GroupID IS NOT NULL AND GroupID <> #Group#) OR GlobalObjectID IN (SELECT GlobalObjectID FROM GlobalObject WHERE RepositoryID IN (SELECT RepositoryID FROM Repository WHERE GroupID <> #Group#));
PolicySandbox WHERE ComponentID NOT IN (SELECT ComponentID FROM Component_Backup) AND PolicySandboxID NOT IN (SELECT PolicySandboxID FROM DocumentReceipt WHERE PolicySandboxID IS NOT NULL );
Component WHERE ComponentID NOT IN (SELECT ComponentID FROM Component_Backup);  
UngroupedHosts; Subtask; Task;
NetworkInterface WHERE NetworkInterfaceID NOT IN (SELECT NetworkInterfaceID FROM Component WHERE ComponentID IN (SELECT ComponentID FROM Component_Backup));  
DNS WHERE DNSID NOT IN (SELECT DNSID FROM NetworkInterface WHERE NetworkInterfaceID IN (SELECT NetworkInterfaceID FROM Component WHERE ComponentID IN (SELECT ComponentID FROM Component_Backup)) AND DNSID IS NOT NULL);
AssetFunctionMember WHERE AssetID NOT IN (SELECT isnull(AssetID,0) FROM NetworkInterface WHERE NetworkInterfaceID IN (SELECT NetworkInterfaceID FROM Component WHERE ComponentID IN (SELECT ComponentID FROM Component_Backup)));
AssetFunction WHERE AssetFunctionID NOT IN (SELECT AssetFunctionID FROM AssetFunctionMember WHERE AssetID IN (SELECT isnull(AssetID,0) FROM NetworkInterface WHERE NetworkInterfaceID IN (SELECT NetworkInterfaceID FROM Component WHERE ComponentID IN (SELECT ComponentID FROM Component_Backup))));
Asset WHERE AssetID NOT IN (SELECT isnull(AssetID,0) FROM NetworkInterface WHERE NetworkInterfaceID IN (SELECT NetworkInterfaceID FROM Component WHERE ComponentID IN (SELECT ComponentID FROM Component_Backup)));
AssetOwner WHERE AssetOwnerID NOT IN (SELECT isnull(AssetOwnerID,0) FROM Asset WHERE AssetID IN (SELECT AssetID FROM NetworkInterface WHERE NetworkInterfaceID IN (SELECT NetworkInterfaceID FROM Component WHERE ComponentID IN (SELECT ComponentID FROM Component_Backup))));
License; LicContactInfo; DeployedPolicy WHERE GroupID <> #Group#;
DeployedPolicy WHERE GroupID = #Group# AND PolicyRepositoryVersionID IN (SELECT PolicyRepositoryVersionID FROM PolicyRepositoryVersion WHERE BinaryDataID IN (SELECT BinaryDataID FROM BinaryData WHERE FileName like ''%/CustomerTokens''));
GroupPolicy; DeploymentJobGroups;
GroupRule WHERE RuleID NOT IN (SELECT RuleID FROM Groups WHERE RuleID IS NOT NULL);
Sites WHERE SiteID >1; SiteRange WHERE SiteRangeID >1; GroupPolicy; Policy; Response;   
PolicyDocumentCollection; 
DeploymentJobPolicyVersions WHERE PolicyRepositoryVersionID NOT IN (SELECT PolicyRepositoryVersionID FROM DeployedPolicy);
DeploymentJob WHERE 
	DeploymentJobID NOT IN (SELECT DeploymentJobID FROM DeploymentJobComponents) AND 
	DeploymentJobID NOT IN (SELECT DeploymentJobID FROM DeploymentJobGroups) AND 
	DeploymentJobID NOT IN (SELECT DeploymentJobID FROM DeploymentJobPolicyVersions);
PolicyRepositoryVersion WHERE 
	PolicyRepositoryVersionID NOT IN (SELECT PolicyRepositoryVersionID FROM DeployedPolicy) AND 
	PolicyRepositoryVersionID NOT IN (SELECT PolicyRepositoryVersionID FROM DocumentReceipt WHERE PolicyRepositoryVersionID IS NOT NULL) AND
	PolicyRepositoryVersionID NOT IN (SELECT PolicyRepositoryVersionID FROM DeploymentJobPolicyVersions);
PolicyRepository WHERE PolicyRepositoryID NOT IN (SELECT PolicyRepositoryID FROM PolicyRepositoryVersion);
GlobalObject WHERE RepositoryID IN (SELECT RepositoryID FROM Repository WHERE GroupID <> #Group#);
Repository WHERE 
	GroupID <> #Group# AND
	RepositoryID NOT IN (SELECT RepositoryID FROM PolicyRepository);
Groups WHERE GroupID NOT IN (#Root#,#Group#); 
ScheduledJobTarget WHERE Type LIKE ''%Group'' OR (TargetID NOT IN (SELECT ComponentID FROM Component_Backup) AND Type LIKE ''%Agent'');
ScheduledJobTarget WHERE ScheduledJobID NOT IN (SELECT ScheduledJobID FROM DeploymentJob);
ScheduledJobRun WHERE ScheduledJobID NOT IN (SELECT ScheduledJobID FROM DeploymentJob);
ScheduledJob WHERE ScheduledJobID NOT IN (SELECT ScheduledJobID FROM DeploymentJob) AND
	ScheduledJobID NOT IN (SELECT ScheduledJobID FROM ScheduledJobRun) AND
	ScheduledJobID NOT IN (SELECT ScheduledJobID FROM ScheduledJobTarget);
ScheduledJobTrigger WHERE ScheduledJobTriggerID NOT IN (SELECT ScheduledJobTriggerID FROM ScheduledJob);
BinaryData WHERE 
	BinaryDataID NOT IN (SELECT PropertyfileID FROM Component_Backup WHERE PropertyfileID IS NOT NULL) AND
	BinaryDataID NOT IN (SELECT ReadmeFileID FROM DesktopAgentVersion WHERE ReadmeFileID IS NOT NULL) AND 
	BinaryDataID NOT IN (SELECT BinaryDataID FROM GlobalObject) AND
	BinaryDataID NOT IN (SELECT BinaryDataID FROM License WHERE BinaryDataID IS NOT NULL) AND
	BinaryDataID NOT IN (SELECT BinaryDataID FROM Policy WHERE BinaryDataID IS NOT NULL) AND
	BinaryDataID NOT IN (SELECT BinaryDataID FROM PolicyDocumentCollection) AND
	BinaryDataID NOT IN (SELECT BinaryDataID FROM PolicyRepositoryVersion) AND 
	BinaryDataID NOT IN (SELECT BinaryDataID FROM PolicySandbox) AND 
	BinaryDataID NOT IN (SELECT BinaryDataID FROM Response WHERE BinaryDataID IS NOT NULL);
ObservanceSiteFilters;
SiteFilterRules; 
SiteFilters; 
ComponentCertificate WHERE GUID NOT IN (SELECT GUID FROM Component_Backup WHERE GUID IS NOT NULL); 
Certificate WHERE CertificateID NOT IN (SELECT CertificateID FROM ComponentCertificate);
ComponentSubscription WHERE ComponentID NOT IN (SELECT ComponentID FROM Component_Backup);
TicketOptions;
TicketRule'

SET @TableList = REPLACE(@TableList, '#Root#', @RootID)
SET @TableList = REPLACE(@TableList, '#Group#', @GroupID)

-- Parse the table list into a local table variable
SELECT @Start = 1
SELECT @TableLength = 1
WHILE @TableLength > 0  
	BEGIN
	SELECT @TableLength = charindex(';',@TableList,@Start)-@Start
	IF @TableLength > 0
		SELECT @TableClause = substring(@TableList,@Start,@TableLength)
	ELSE
		SELECT @TableClause = substring(@TableList,@Start,len(@TableList)-@Start+1)
	SELECT @Start = @Start + @TableLength + 1
	INSERT INTO @Tables (TableName) VALUES(@TableClause)
	END

--exec delete statements
DECLARE c3 CURSOR LOCAL FOR
SELECT 	TableName
FROM 	@Tables

OPEN c3
FETCH NEXT FROM c3 INTO @DeleteTable
WHILE @@FETCH_STATUS = 0
	BEGIN
	SELECT @SQLString = 'DELETE FROM ' + @DeleteTable
	EXEC(@SQLString)

	IF @@ERROR <> 0 RETURN(1)

	FETCH NEXT FROM c3 INTO @DeleteTable
	END
CLOSE c3
DEALLOCATE c3

--Reset policy count columns
UPDATE PolicyRepositoryVersion
SET DeploymentCount = (SELECT COUNT(*) FROM DeployedPolicy dp WHERE dp.PolicyRepositoryVersionID = PolicyRepositoryVersion.PolicyRepositoryVersionID),
    ScheduledCount = (SELECT COUNT(*) FROM DeploymentJobPolicyVersions dj 
			INNER JOIN DeploymentJob d
			ON dj.DeploymentJobID = d.DeploymentJobID
			INNER JOIN ScheduledJob j
			ON d.ScheduledJobID = j.ScheduledJobID
			INNER JOIN ScheduledJobTrigger t
			ON j.ScheduledJobTriggerID = t.ScheduledJobTriggerID
			INNER JOIN ScheduledJobTarget tgt
			ON j.ScheduledJobID = tgt.ScheduledJobID
			WHERE t.TriggerState IN ('waiting')
			AND dj.PolicyRepositoryVersionID = PolicyRepositoryVersion.PolicyRepositoryVersionID)

IF @@ERROR <> 0 RETURN(1)

RETURN(0)
GO
