IF OBJECT_ID('iss_Failover_Site_CreateTables') IS NOT NULL DROP PROCEDURE dbo.iss_Failover_Site_CreateTables
go
CREATE PROCEDURE dbo.iss_Failover_Site_CreateTables
@IsPrimaryExport TINYINT = 0
AS
/* IBM Confidential - OCO Source Materials */
/* Copyright (c) IBM Corp. 1992, 2007 */
/* Copyright (c) Internet Security Systems, Inc. 1992-2006 */
/* The source code for this program is not published or otherwise divested of its trade secrets, */
/* irrespective of what has been deposited with the U.S. Copyright Office. */ 
DECLARE @SaveErrNbr int, @SaveRowCnt int, @FirstError int, @RetVal int, @ProcName sysname 
SELECT @ProcName = OBJECT_NAME(@@ProcID)
SET NOCOUNT ON
-- iss_error error-number, severity, proc-name, relates-to-errorid, raise-params, errorid (OUT)

DECLARE @SQL nvarchar(4000),  @TotalRowsImported int,  @TableCount bigint

/*
Create special tables first
*/
IF OBJECT_ID('ExportSiteIP_Recovery') IS NOT NULL DROP TABLE dbo.ExportSiteIP_Recovery
CREATE TABLE dbo.ExportSiteIP_Recovery (
 HostIPAddress        varchar(47) NULL,
 HostNBName           nvarchar(16) NULL,
 DBHostIPAddress      varchar(47) NULL,
 DBHostNBName	      nvarchar(16) NULL,
 DBServerName         nvarchar(255) NULL,
 IsPrimary	      bit NULL
)
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ExportSiteIP_Recovery', null
	RETURN(1)
	END

/*
Copy automated CREATE TABLE dbo.statements from here to end of procedure
*/
IF OBJECT_ID('ACL_Recovery') IS NOT NULL DROP TABLE dbo.ACL_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.ACL_Recovery(
	ACLID	int	NOT NULL
	,OwnerPrincipalID	int	NULL
	,Version	int	NOT NULL
	,FO_ACLID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ACL_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('ActionDetails_Recovery') IS NOT NULL DROP TABLE dbo.ActionDetails_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.ActionDetails_Recovery(
	ActionDetailsID	int	NOT NULL
	,ActionType	numeric(18,0)	NOT NULL
	,Arguments	ntext	NULL
	,ComponentGroupID	int	NULL
	,ComponentID	int	NULL
	,ControllerID	int	NULL
	,Deleted	numeric(18,0)	NOT NULL
	,HostGroupID	int	NULL
	,ItemID	int	NULL
	,LastModifiedAt	datetime	NULL
	,LastModifiedBy	nvarchar(60)	NULL
	,NetworkInterfaceID	int	NULL
	,NextRunDate	datetime	NULL
	,PrincipalIDList	text	NULL
	,RoleID	int	NULL
	,ScheduledBy	nvarchar(60)	NOT NULL
	,ScheduleID	int	NULL
	,Suspended	numeric(18,0)	NOT NULL
	,FO_ActionDetailsID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ActionDetails_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('ActionJob_Recovery') IS NOT NULL DROP TABLE dbo.ActionJob_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.ActionJob_Recovery(
	ActionDetailsID	int	NOT NULL
	,ActionJobID	int	NOT NULL
	,ActionJobInfo	varchar(100)	NULL
	,ActionState	numeric(18,0)	NOT NULL
	,ComponentID	int	NULL
	,DateCreated	datetime	NOT NULL
	,LastModifiedAt	datetime	NOT NULL
	,Result	varchar(300)	NULL
	,StartDateTime	datetime	NOT NULL
	,FO_ActionJobID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ActionJob_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Asset_Recovery') IS NOT NULL DROP TABLE dbo.Asset_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Asset_Recovery(
	AssetCriticality	tinyint	NOT NULL
	,AssetID	int	NOT NULL
	,AssetOwnerID	int	NULL
	,Domain	nvarchar(16)	NULL
	,GUID	varchar(36)	NULL
	,HostName	nvarchar(16)	NULL
	,InventoryTag	nvarchar(64)	NULL
	,ISScanDate	datetime	NULL
	,LastModifiedAt	datetime	NULL
	,LastModifiedBy	int	NULL
	,LastScannedAt	datetime	NULL
	,OSCertainty	tinyint	NOT NULL
	,OSGroupID	int	NULL
	,OSLastModifiedAt	datetime	NULL
	,OSName	nvarchar(64)	NULL
	,OSSuppliedByProductID	smallint	NULL
	,OSVersion	nvarchar(32)	NULL
	,StatNameID	tinyint	NULL
	,FO_AssetID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Asset_Recovery', null
	RETURN(1)
	END

IF @IsPrimaryExport = 0
CREATE CLUSTERED INDEX Asset_Recovery_PK ON Asset_Recovery(AssetID)
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Asset_Recovery:Asset_Recovery_PK', null
	RETURN(1)
	END

IF OBJECT_ID('AssetCriticality_Recovery') IS NOT NULL DROP TABLE dbo.AssetCriticality_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.AssetCriticality_Recovery(
	AssetCriticality	tinyint	NOT NULL
	,AssetCriticalityDesc	nvarchar(60)	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'AssetCriticality_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('AssetFunction_Recovery') IS NOT NULL DROP TABLE dbo.AssetFunction_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.AssetFunction_Recovery(
	AssetFunctionID	int	NOT NULL
	,AssetFunctionName	nvarchar(128)	NOT NULL
	,FO_AssetFunctionID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'AssetFunction_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('AssetFunctionMember_Recovery') IS NOT NULL DROP TABLE dbo.AssetFunctionMember_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.AssetFunctionMember_Recovery(
	AssetFunctionID	int	NOT NULL
	,AssetID	int	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'AssetFunctionMember_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('AssetOwner_Recovery') IS NOT NULL DROP TABLE dbo.AssetOwner_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.AssetOwner_Recovery(
	AssetOwnerID	int	NOT NULL
	,AssetOwnerName	nvarchar(60)	NOT NULL
	,FO_AssetOwnerID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'AssetOwner_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('BinaryData_Recovery') IS NOT NULL DROP TABLE dbo.BinaryData_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.BinaryData_Recovery(
	BinaryDataID	int	NOT NULL
	,BinaryDataType	tinyint	NULL
	,CheckSum	int	NULL
	,DeleteRefCount	int	NULL
	,FileName	nvarchar(255)	NULL
	,LastModifiedAt	datetime	NULL
	,LastModifiedByPrincipalID	int	NULL
	,MIMEType	varchar(50)	NULL
	,Secured	tinyint	NOT NULL
	,Value	image	NULL
	,FO_BinaryDataID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'BinaryData_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Certificate_Recovery') IS NOT NULL DROP TABLE dbo.Certificate_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Certificate_Recovery(
	Certificate	image	NULL
	,CertificateID	int	NOT NULL
	,CheckSum	int	NOT NULL
	,FO_CertificateID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Certificate_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Component_Recovery') IS NOT NULL DROP TABLE dbo.Component_Recovery
CREATE TABLE dbo.Component_Recovery(
	AlertEventPort	int	NULL
	,AlertEventSourcePort	int	NULL
	,AvailableXPU	varchar(40)	NULL
	,ComponentID	int	NOT NULL
	,DaemonPort	int	NULL
	,Deleted	numeric(18,0)	NOT NULL
	,ECStateDescription	nvarchar(500)	NULL
	,ECStatus	tinyint	NULL
	,EventCollectorID	int	NULL
	,EventLogOption	tinyint	NULL
	,EventPort	int	NULL
	,EventSourcePort	int	NULL
	,FCPEventPort	int	NULL
	,FCPEventSourcePort	int	NULL
	,GUID	varchar(36)	NULL
	,Hide	tinyint	NOT NULL
	,LastHeartBeat	datetime	NULL
	,LastInstalledXPU	varchar(40)	NULL
	,LastInstalledXPUDate	datetime	NULL
	,LastModifiedAt	datetime	NULL
	,LastModifiedBy	nvarchar(60)	NULL
	,LastPushedPolicyID	int	NULL
	,LastPushedResponseID	int	NULL
	,LicenseID	int	NULL
	,LicenseState	smallint	NULL
	,LicensingModel	tinyint	NOT NULL
	,LoggingLevel	tinyint	NULL
	,Master	varchar(30)	NULL
	,ModelDesc	varchar(1000)	NULL
	,ModifiedBySensorController	tinyint	NOT NULL
	,NetworkInterfaceID	int	NOT NULL
	,OnDemandStatus	smallint	NULL
	,OptionFlags	int	NULL
	,Policy	nvarchar(434)	NULL
	,PolicyChangedFlag	tinyint	NOT NULL
	,PolicyGroupID	int	NULL
	,Priority	numeric(18,0)	NOT NULL
	,PropertyFileID	int	NULL
	,Response	nvarchar(434)	NULL
	,RoleID	int	NULL
	,Sandbox	tinyint	NULL
	,SensorName	nvarchar(100)	NULL
	,StateDescription	nvarchar(500)	NULL
	,Status	numeric(18,0)	NOT NULL
	,UnexpectedConfigChange	tinyint	NULL
	,Version	varchar(40)	NULL
	,XPUDate	datetime	NULL
	,XPUState	smallint	NOT NULL
	,XPUStateDescription	varchar(128)	NULL
	,FO_ComponentID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Component_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('ComponentCertificate_Recovery') IS NOT NULL DROP TABLE dbo.ComponentCertificate_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.ComponentCertificate_Recovery(
	CertificateID	int	NOT NULL
	,ComponentCertificateID	int	NOT NULL
	,GUID	varchar(36)	NOT NULL
	,LastModifiedAt	datetime	NULL
	,Purpose	smallint	NULL
	,FO_ComponentCertificateID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ComponentCertificate_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('ComponentSubscription_Recovery') IS NOT NULL DROP TABLE dbo.ComponentSubscription_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.ComponentSubscription_Recovery(
	ComponentID	int	NOT NULL
	,ExpirationDate	datetime	NOT NULL
	,NamespaceID	smallint	NOT NULL
	,ServiceNamespaceID	smallint	NOT NULL
	,Version	varchar(100)	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ComponentSubscription_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('DeployedPolicy_Recovery') IS NOT NULL DROP TABLE dbo.DeployedPolicy_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.DeployedPolicy_Recovery(
	ComponentID	int	NULL
	,DeployedByPrincipalID	int	NULL
	,DeployedPolicyID	int	NOT NULL
	,DeployTime	datetime	NOT NULL
	,GroupID	int	NULL
	,NamespaceID	smallint	NOT NULL
	,PolicyRepositoryVersionID	int	NOT NULL
	,SchemaVersion	varchar(100)	NOT NULL
	,FO_DeployedPolicyID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'DeployedPolicy_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('DeploymentJob_Recovery') IS NOT NULL DROP TABLE dbo.DeploymentJob_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.DeploymentJob_Recovery(
	Action	int	NOT NULL
	,AgentModeKey	varchar(60)	NULL
	,AgentNamespace	varchar(255)	NOT NULL
	,AgentVersion	varchar(60)	NOT NULL
	,DeploymentJobID	int	NOT NULL
	,ForceHeartbeat	tinyint	NOT NULL
	,ResponseName	varchar(80)	NULL
	,ScheduledJobID	int	NOT NULL
	,SchedulerPrincipalID	int	NULL
	,FO_DeploymentJobID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'DeploymentJob_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('DeploymentJobComponents_Recovery') IS NOT NULL DROP TABLE dbo.DeploymentJobComponents_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.DeploymentJobComponents_Recovery(
	ComponentID	int	NOT NULL
	,DeploymentJobID	int	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'DeploymentJobComponents_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('DeploymentJobGroups_Recovery') IS NOT NULL DROP TABLE dbo.DeploymentJobGroups_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.DeploymentJobGroups_Recovery(
	DeploymentJobID	int	NOT NULL
	,GroupID	int	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'DeploymentJobGroups_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('DeploymentJobPolicyVersions_Recovery') IS NOT NULL DROP TABLE dbo.DeploymentJobPolicyVersions_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.DeploymentJobPolicyVersions_Recovery(
	DeploymentJobID	int	NOT NULL
	,PolicyRepositoryVersionID	int	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'DeploymentJobPolicyVersions_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('DesktopAgentVersion_Recovery') IS NOT NULL DROP TABLE dbo.DesktopAgentVersion_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.DesktopAgentVersion_Recovery(
	GUID	varchar(36)	NOT NULL
	,ReadmeFileID	int	NULL
	,RoleID	int	NOT NULL
	,Version	varchar(40)	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'DesktopAgentVersion_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('DNS_Recovery') IS NOT NULL DROP TABLE dbo.DNS_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.DNS_Recovery(
	DNSID	int	NOT NULL
	,DNSName	nvarchar(254)	NOT NULL
	,FO_DNSID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'DNS_Recovery', null
	RETURN(1)
	END

IF @IsPrimaryExport = 0	
CREATE CLUSTERED INDEX DNS_Recovery_PK ON DNS_Recovery(DNSID)
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'DNS_Recovery:DNS_Recovery_PK', null
	RETURN(1)
	END

IF OBJECT_ID('DocumentReceipt_Recovery') IS NOT NULL DROP TABLE dbo.DocumentReceipt_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.DocumentReceipt_Recovery(
	ComponentID	int	NOT NULL
	,GlobalObjectID	int	NULL
	,GroupID	int	NULL
	,LastModifiedAt	datetime	NOT NULL
	,NamespaceID	smallint	NOT NULL
	,PolicyRepositoryVersionID	int	NULL
	,PolicySandboxID	int	NULL
	,Version	varchar(100)	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'DocumentReceipt_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('GlobalObject_Recovery') IS NOT NULL DROP TABLE dbo.GlobalObject_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.GlobalObject_Recovery(
	BinaryDataID	int	NOT NULL
	,GlobalObjectID	int	NOT NULL
	,NamespaceID	smallint	NOT NULL
	,RepositoryID	int	NULL
	,SchemaVersion	varchar(100)	NOT NULL
	,FO_GlobalObjectID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'GlobalObject_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('GrantList_Recovery') IS NOT NULL DROP TABLE dbo.GrantList_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.GrantList_Recovery(
	ACLID	int	NOT NULL
	,GrantListID	int	NOT NULL
	,PermissionActionID	int	NOT NULL
	,PermissionTargetID	int	NOT NULL
	,PrincipalID	int	NOT NULL
	,FO_GrantListID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'GrantList_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('GroupHostLinks_Recovery') IS NOT NULL DROP TABLE dbo.GroupHostLinks_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.GroupHostLinks_Recovery(
	GroupID	int	NOT NULL
	,NetworkInterfaceID	int	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'GroupHostLinks_Recovery', null
	RETURN(1)
	END
	
IF @IsPrimaryExport = 0
CREATE CLUSTERED INDEX GHL_Recovery_PK ON GroupHostLinks_Recovery(GroupID, NetworkInterfaceID)
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'GroupHostLinks_Recovery:GHL_Recovery_PK', null
	RETURN(1)
	END

IF OBJECT_ID('GroupPolicy_Recovery') IS NOT NULL DROP TABLE dbo.GroupPolicy_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.GroupPolicy_Recovery(
	GroupID	int	NOT NULL
	,PolicyID	int	NOT NULL
	,RoleID	int	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'GroupPolicy_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('GroupRule_Recovery') IS NOT NULL DROP TABLE dbo.GroupRule_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.GroupRule_Recovery(
	Description	nvarchar(254)	NULL
	,LastModifiedAt	datetime	NULL
	,RuleID	int	NOT NULL
	,RuleType	tinyint	NOT NULL
	,RuleValue	ntext	NOT NULL
	,FO_RuleID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'GroupRule_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Groups_Recovery') IS NOT NULL DROP TABLE dbo.Groups_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Groups_Recovery(
	ACLID	int	NULL
	,AutoTicketGroupByAsset	tinyint	NULL
	,Deleted	tinyint	NULL
	,GroupDesc	nvarchar(255)	NULL
	,GroupID	int	NOT NULL
	,GroupName	nvarchar(80)	NOT NULL
	,GroupTypeID	int	NULL
	,GroupViewID	int	NULL
	,GUID	varchar(36)	NULL
	,InheritedACL	bit	NULL
	,ParentGroupID	int	NULL
	,RoleID	int	NULL
	,RuleID	int	NULL
	,SiteID	int	NULL
	,SPGroupID	int	NULL
	,FO_GroupID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Groups_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('LicContactInfo_Recovery') IS NOT NULL DROP TABLE dbo.LicContactInfo_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.LicContactInfo_Recovery(
	AdditionalInfo	nvarchar(255)	NULL
	,Address1	nvarchar(255)	NULL
	,Address2	nvarchar(255)	NULL
	,City	nvarchar(100)	NULL
	,CompanyName	nvarchar(255)	NULL
	,Country	nvarchar(60)	NULL
	,Email	nvarchar(255)	NULL
	,LicContactInfoGUID	nvarchar(40)	NOT NULL
	,PostCode	nvarchar(40)	NULL
	,State	nvarchar(50)	NULL
	,SubjectName	nvarchar(255)	NOT NULL
	,Title	nvarchar(100)	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'LicContactInfo_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('License_Recovery') IS NOT NULL DROP TABLE dbo.License_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.License_Recovery(
	BinaryDataID	int	NULL
	,Description	nvarchar(100)	NULL
	,DeviceCount	int	NULL
	,ExpireDate	varchar(40)	NULL
	,FeatureDescription	nvarchar(100)	NULL
	,Features	nvarchar(50)	NULL
	,KeyString	varchar(50)	NULL
	,LicContactInfoGUID	nvarchar(40)	NULL
	,LicenseID	int	NOT NULL
	,LicenseType	tinyint	NOT NULL
	,LicGUID	nvarchar(40)	NULL
	,MaintenanceDate	varchar(40)	NULL
	,Name	nvarchar(50)	NULL
	,NewLicenseID	int	NULL
	,State	tinyint	NULL
	,StateDescription	varchar(512)	NULL
	,StatNameID	int	NULL
	,FO_LicenseID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'License_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Namespace_Recovery') IS NOT NULL DROP TABLE dbo.Namespace_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Namespace_Recovery(
	Namespace	varchar(255)	NOT NULL
	,NamespaceID	smallint	NOT NULL
	,FO_NamespaceID	smallint	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Namespace_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('NetworkInterface_Recovery') IS NOT NULL DROP TABLE dbo.NetworkInterface_Recovery
CREATE TABLE dbo.NetworkInterface_Recovery(
	AssetID	int	NULL
	,DateAdded	datetime	NOT NULL
	,DNSID	int	NULL
	,HostNameResolved	tinyint	NULL
	,IPV4Address	varchar(47)	NULL
	,IPV4Nbr	numeric(10,0)	NULL
	,IPV6Address	varchar(39)	NULL
	,IPv6High	bigint	NULL
	,IPv6Low	bigint	NULL
	,LastModifiedAt	datetime	NOT NULL
	,MACAddress	varchar(17)	NULL
	,NetworkInterfaceID	int	NOT NULL
	,FO_NetworkInterfaceID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'NetworkInterface_Recovery', null
	RETURN(1)
	END
	
CREATE CLUSTERED INDEX NI_Recovery_PK ON NetworkInterface_Recovery(NetworkInterfaceID)
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'NetworkInterface_Recovery:NI_Recovery_PK', null
	RETURN(1)
	END
	
CREATE NONCLUSTERED INDEX NI_Recovery_AK1 ON NetworkInterface_Recovery(AssetID)
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'NetworkInterface_Recovery:NI_Recovery_AK1', null
	RETURN(1)
	END
	
CREATE NONCLUSTERED INDEX NI_Recovery_AK2 ON NetworkInterface_Recovery(DNSID)
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'NetworkInterface_Recovery:NI_Recovery_AK2', null
	RETURN(1)
	END

CREATE NONCLUSTERED INDEX NI_Recovery_AK3 ON NetworkInterface_Recovery(FO_NetworkInterfaceID)
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'NetworkInterface_Recovery:NI_Recovery_AK3', null
	RETURN(1)
	END

IF OBJECT_ID('NTGroup_Recovery') IS NOT NULL DROP TABLE dbo.NTGroup_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.NTGroup_Recovery(
	NTGroupName	varchar(255)	NULL
	,PrincipalID	int	NOT NULL
	,SID	varchar(50)	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'NTGroup_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('ObjectACL_Recovery') IS NOT NULL DROP TABLE dbo.ObjectACL_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.ObjectACL_Recovery(
	ACLID	int	NOT NULL
	,ObjectName	varchar(32)	NOT NULL
	,ObjectType	varchar(32)	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ObjectACL_Recovery', null
	RETURN(1)
	END
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       

IF OBJECT_ID('PermissionAction_Recovery') IS NOT NULL DROP TABLE dbo.PermissionAction_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.PermissionAction_Recovery(
	ActionDisplayName	nvarchar(255)	NOT NULL
	,PermissionActionID	int	NOT NULL
	,PermissionActionName	nvarchar(255)	NOT NULL
	,FO_PermissionActionID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'PermissionAction_Recovery', null
	RETURN(1)
	END
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       

IF OBJECT_ID('PermissionTarget_Recovery') IS NOT NULL DROP TABLE dbo.PermissionTarget_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.PermissionTarget_Recovery(
	PermissionTargetID	int	NOT NULL
	,PermissionTargetName	nvarchar(255)	NOT NULL
	,TargetDisplayName	nvarchar(255)	NOT NULL
	,FO_PermissionTargetID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'PermissionTarget_Recovery', null
	RETURN(1)
	END
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       

IF OBJECT_ID('Policy_Recovery') IS NOT NULL DROP TABLE dbo.Policy_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Policy_Recovery(
	ACLID	int	NULL
	,BinaryDataID	int	NULL
	,Deleted	numeric(18,0)	NOT NULL
	,Description	nvarchar(80)	NULL
	,EditorKey	varchar(50)	NOT NULL
	,FileName	nvarchar(255)	NULL
	,LastModifiedAt	datetime	NULL
	,LastModifiedBy	nvarchar(60)	NULL
	,Name	nvarchar(150)	NOT NULL
	,PolicyID	int	NOT NULL
	,ReadOnly	tinyint	NULL
	,RoleID	int	NULL
	,Valid	tinyint	NOT NULL
	,Version	varchar(100)	NULL
	,FO_PolicyID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Policy_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('PolicyDocumentCollection_Recovery') IS NOT NULL DROP TABLE dbo.PolicyDocumentCollection_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.PolicyDocumentCollection_Recovery(
	BinaryDataID	int	NOT NULL
	,Guid	varchar(36)	NOT NULL
	,NamespaceID	smallint	NOT NULL
	,PolicyDocumentCollectionID	int	NOT NULL
	,SchemaVersion	varchar(100)	NOT NULL
	,FO_PolicyDocumentCollectionID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'PolicyDocumentCollection_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('PolicyRepository_Recovery') IS NOT NULL DROP TABLE dbo.PolicyRepository_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.PolicyRepository_Recovery(
	LastModifiedAt	datetime	NULL
	,Name	nvarchar(100)	NOT NULL
	,NamespaceID	smallint	NOT NULL
	,PolicyRepositoryID	int	NOT NULL
	,RepositoryID	int	NOT NULL
	,SchemaVersion	varchar(100)	NOT NULL
	,FO_PolicyRepositoryID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'PolicyRepository_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('PolicyRepositoryVersion_Recovery') IS NOT NULL DROP TABLE dbo.PolicyRepositoryVersion_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.PolicyRepositoryVersion_Recovery(
	BinaryDataID	int	NOT NULL
	,DeploymentCount	int	NOT NULL
	,LastModifiedAt	datetime	NOT NULL
	,LastModifiedByPrincipalID	int	NULL
	,PolicyRepositoryID	int	NOT NULL
	,PolicyRepositoryVersionID	int	NOT NULL
	,ScheduledCount	int	NOT NULL
	,UserComment	nvarchar(255)	NULL
	,Version	int	NOT NULL
	,FO_PolicyRepositoryVersionID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'PolicyRepositoryVersion_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('PolicySandbox_Recovery') IS NOT NULL DROP TABLE dbo.PolicySandbox_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.PolicySandbox_Recovery(
	BinaryDataID	int	NOT NULL
	,ComponentID	int	NOT NULL
	,NamespaceID	smallint	NOT NULL
	,PolicySandboxID	int	NOT NULL
	,SchemaVersion	varchar(100)	NOT NULL
	,FO_PolicySandboxID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'PolicySandbox_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Principal_Recovery') IS NOT NULL DROP TABLE dbo.Principal_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Principal_Recovery(
	PrincipalID	int	NOT NULL
	,FO_PrincipalID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Principal_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('ReportInstance_Recovery') IS NOT NULL DROP TABLE dbo.ReportInstance_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.ReportInstance_Recovery(
	Arguments	ntext	NULL
	,CreatedByPrincipalID	int	NULL
	,DateCreated	datetime	NOT NULL
	,EmailUserIDList	ntext	NULL
	,GroupID	int	NULL
	,LastModifiedAt	datetime	NOT NULL
	,LastModifiedBy	nvarchar(255)	NULL
	,Recursion	tinyint	NOT NULL
	,ReportCategory	nvarchar(255)	NULL
	,ReportFilePath	nvarchar(1000)	NULL
	,ReportInstanceID	int	NOT NULL
	,ReportName	nvarchar(255)	NULL
	,Shared	tinyint	NOT NULL
	,TemplateFileName	nvarchar(255)	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ReportInstance_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Repository_Recovery') IS NOT NULL DROP TABLE dbo.Repository_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Repository_Recovery(
	GroupID	int	NOT NULL
	,RepositoryID	int	NOT NULL
	,FO_RepositoryID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Repository_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Response_Recovery') IS NOT NULL DROP TABLE dbo.Response_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Response_Recovery(
	ACLID	int	NULL
	,BinaryDataID	int	NULL
	,Deleted	numeric(18,0)	NOT NULL
	,Description	nvarchar(80)	NULL
	,EditorKey	varchar(50)	NOT NULL
	,FileName	nvarchar(255)	NULL
	,LastModifiedAt	datetime	NULL
	,LastModifiedBy	nvarchar(60)	NULL
	,Name	nvarchar(150)	NOT NULL
	,ReadOnly	tinyint	NULL
	,ResponseID	int	NOT NULL
	,RoleID	int	NULL
	,Valid	tinyint	NOT NULL
	,Version	varchar(100)	NULL
	,FO_ResponseID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Response_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Schedule_Recovery') IS NOT NULL DROP TABLE dbo.Schedule_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Schedule_Recovery(
	ActiveEndDate	numeric(18,0)	NULL
	,ActiveEndTOD	numeric(18,0)	NULL
	,ActiveStartDate	numeric(18,0)	NULL
	,ActiveStartTOD	numeric(18,0)	NULL
	,Deleted	numeric(18,0)	NOT NULL
	,Description	varchar(1000)	NULL
	,Enabled	numeric(18,0)	NOT NULL
	,FreqInterval	numeric(18,0)	NOT NULL
	,FreqRecurFactor	numeric(18,0)	NULL
	,FreqRelativeInt	numeric(18,0)	NOT NULL
	,FreqSubInterval	numeric(18,0)	NOT NULL
	,FreqSubType	numeric(18,0)	NULL
	,FreqType	numeric(18,0)	NOT NULL
	,NumSchedScans	numeric(18,0)	NULL
	,ScheduleID	int	NOT NULL
	,TimeZone	varchar(40)	NULL
	,FO_ScheduleID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Schedule_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('ScheduledJob_Recovery') IS NOT NULL DROP TABLE dbo.ScheduledJob_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.ScheduledJob_Recovery(
	Category	varchar(80)	NOT NULL
	,CommandClassname	varchar(300)	NOT NULL
	,CommandID	int	NULL
	,Description	nvarchar(300)	NULL
	,Name	varchar(60)	NOT NULL
	,ScheduledByPrincipalID	int	NOT NULL
	,ScheduledJobID	int	NOT NULL
	,ScheduledJobTriggerID	int	NOT NULL
	,FO_ScheduledJobID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ScheduledJob_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('ScheduledJobRun_Recovery') IS NOT NULL DROP TABLE dbo.ScheduledJobRun_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.ScheduledJobRun_Recovery(
	RunTime	datetime	NULL
	,ScheduledJobID	int	NOT NULL
	,ScheduledJobRunID	int	NOT NULL
	,Status	smallint	NULL
	,FO_ScheduledJobRunID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ScheduledJobRun_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('ScheduledJobTarget_Recovery') IS NOT NULL DROP TABLE dbo.ScheduledJobTarget_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.ScheduledJobTarget_Recovery(
	ScheduledJobID	int	NOT NULL
	,ScheduledJobTargetID	int	NOT NULL
	,TargetID	int	NOT NULL
	,Type	varchar(60)	NOT NULL
	,FO_ScheduledJobTargetID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ScheduledJobTarget_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('ScheduledJobTrigger_Recovery') IS NOT NULL DROP TABLE dbo.ScheduledJobTrigger_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.ScheduledJobTrigger_Recovery(
	CronExpression	varchar(60)	NULL
	,Description	nvarchar(300)	NULL
	,EndTime	datetime	NULL
	,LastScheduledJobRunID	int	NULL
	,Name	varchar(60)	NULL
	,NextScheduledJobRunID	int	NULL
	,Priority	int	NULL
	,ScheduledJobTriggerID	int	NOT NULL
	,StartTime	datetime	NULL
	,TimeZone	varchar(40)	NULL
	,TriggerState	varchar(60)	NULL
	,FO_ScheduledJobTriggerID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'ScheduledJobTrigger_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('SiteFilterRules_Recovery') IS NOT NULL DROP TABLE dbo.SiteFilterRules_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.SiteFilterRules_Recovery(
	BeginDestAddressInt	numeric(10,0)	NULL
	,BeginSrcAddressInt	numeric(10,0)	NULL
	,EndDestAddressInt	numeric(10,0)	NULL
	,EndSrcAddressInt	numeric(10,0)	NULL
	,ObservanceType	tinyint	NULL
	,SiteFilterEndDate	datetime	NULL
	,SiteFilterID	int	NOT NULL
	,SiteFilterRuleID	int	NOT NULL
	,SiteFilterStartDate	datetime	NULL
	,TagNameIn	nvarchar(120)	NULL
	,TagNameLike	nvarchar(120)	NULL
	,TargetObjectNameLike	nvarchar(200)	NULL
	,TargetObjectType	tinyint	NULL
	,VulnStatusIn	varchar(900)	NULL
	,FO_SiteFilterRuleID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'SiteFilterRules_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('SiteFilters_Recovery') IS NOT NULL DROP TABLE dbo.SiteFilters_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.SiteFilters_Recovery(
	CreatedBy	varchar(60)	NULL
	,DateModified	datetime	NULL
	,Deleted	tinyint	NULL
	,FusionIgnoreFlag	bit	NOT NULL
	,SiteFilterDesc	ntext	NULL
	,SiteFilterID	int	NOT NULL
	,SiteFilterName	nvarchar(60)	NULL
	,SiteFilterTypeID	int	NULL
	,FO_SiteFilterID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'SiteFilters_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('SiteRange_Recovery') IS NOT NULL DROP TABLE dbo.SiteRange_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.SiteRange_Recovery(
	Description	nvarchar(64)	NULL
	,EndIPNbr	numeric(10,0)	NULL
	,SiteRangeID	smallint	NOT NULL
	,StartIPNbr	numeric(10,0)	NULL
	,FO_SiteRangeID	smallint	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'SiteRange_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Sites_Recovery') IS NOT NULL DROP TABLE dbo.Sites_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Sites_Recovery(
	Deleted	tinyint	NULL
	,Descr	nvarchar(255)	NULL
	,GUID	varchar(512)	NULL
	,IpAddress	varchar(47)	NOT NULL
	,LastDataLoadAt	datetime	NULL
	,Name	nvarchar(60)	NOT NULL
	,Port	int	NOT NULL
	,ReportServerHostName	nvarchar(60)	NULL
	,SiteID	int	NOT NULL
	,WithADGroup	bit	NOT NULL
	,FO_SiteID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Sites_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('SPUserGroup_Recovery') IS NOT NULL DROP TABLE dbo.SPUserGroup_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.SPUserGroup_Recovery(
	PrincipalID	int	NOT NULL
	,SPUserGroupDesc	varchar(255)	NULL
	,SPUserGroupName	nvarchar(255)	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'SPUserGroup_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('SPUserGroupMember_Recovery') IS NOT NULL DROP TABLE dbo.SPUserGroupMember_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.SPUserGroupMember_Recovery(
	PrincipalID	int	NOT NULL
	,SPUserGroupMemberID	int	NOT NULL
	,SPUserGroupPrincipalID	int	NOT NULL
	,FO_SPUserGroupMemberID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'SPUserGroupMember_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('SubTask_Recovery') IS NOT NULL DROP TABLE dbo.SubTask_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.SubTask_Recovery(
	Arguments	varchar(512)	NULL
	,AssignedComponentID	int	NULL
	,CompletedUnits	int	NULL
	,CreatedBy	varchar(50)	NOT NULL
	,DateCreated	datetime	NOT NULL
	,GroupID	int	NULL
	,IsActive	tinyint	NOT NULL
	,IsFinished	tinyint	NOT NULL
	,LastModifiedAt	datetime	NOT NULL
	,LastObject	varchar(255)	NULL
	,LastRoleID	int	NULL
	,LastSubject	varchar(255)	NULL
	,ParentSubTaskID	int	NULL
	,Priority	int	NOT NULL
	,SubTaskID	int	NOT NULL
	,SubTaskNamespaceID	smallint	NOT NULL
	,TargetComponentGUID	varchar(36)	NULL
	,TaskID	int	NOT NULL
	,TimeOut	int	NULL
	,TotalUnits	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'SubTask_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Task_Recovery') IS NOT NULL DROP TABLE dbo.Task_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Task_Recovery(
	Arguments	varchar(512)	NULL
	,CreatedBy	varchar(50)	NOT NULL
	,DateCreated	datetime	NOT NULL
	,EndDate	datetime	NULL
	,GroupID	int	NULL
	,InstanceTimeStamp	datetime	NOT NULL
	,IsFinished	tinyint	NOT NULL
	,LastModifiedAt	datetime	NOT NULL
	,PrincipalIDList	text	NULL
	,Priority	int	NOT NULL
	,RoleID	int	NULL
	,StartDate	datetime	NULL
	,Status	int	NOT NULL
	,TaskDescription	nvarchar(64)	NULL
	,TaskGUID	varchar(36)	NOT NULL
	,TaskID	int	NOT NULL
	,TaskNamespaceID	smallint	NOT NULL
	,FO_TaskID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Task_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('TicketOptions_Recovery') IS NOT NULL DROP TABLE dbo.TicketOptions_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.TicketOptions_Recovery(
	DefaultValue	nvarchar(800)	NOT NULL
	,IsEmailResponse	bit	NOT NULL
	,LastModifiedAt	datetime	NOT NULL
	,LastModifiedBy	nvarchar(60)	NOT NULL
	,OptionName	varchar(100)	NOT NULL
	,ParamDesc	nvarchar(250)	NULL
	,ParamValue	nvarchar(800)	NOT NULL
	,System_Usr	nvarchar(60)	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'TicketOptions_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('TicketPriority_Recovery') IS NOT NULL DROP TABLE dbo.TicketPriority_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.TicketPriority_Recovery(
	Active	bit	NOT NULL
	,DefaultLatency	int	NOT NULL
	,StockPriority	bit	NOT NULL
	,TicketPriorityDescription	nvarchar(3000)	NULL
	,TicketPriorityID	int	NOT NULL
	,TicketPriorityName	nvarchar(255)	NOT NULL
	,FO_TicketPriorityID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'TicketPriority_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('TicketProvider_Recovery') IS NOT NULL DROP TABLE dbo.TicketProvider_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.TicketProvider_Recovery(
	Active	bit	NOT NULL
	,ClassName	varchar(255)	NULL
	,ProviderDescription	nvarchar(3000)	NULL
	,ProviderID	int	NOT NULL
	,ProviderName	nvarchar(255)	NULL
	,FO_ProviderID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'TicketProvider_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('TicketRule_Recovery') IS NOT NULL DROP TABLE dbo.TicketRule_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.TicketRule_Recovery(
	AssetCriticality	tinyint	NULL
	,AssetCriticalityCO	char(2)	NULL
	,AssetFunctionID	int	NULL
	,AssetFunctionIDCO	char(2)	NULL
	,AssetOSName	nvarchar(64)	NULL
	,AssetOSNameCO	char(2)	NULL
	,CVSSScore	tinyint	NULL
	,CVSSScoreCO	char(2)	NULL
	,Enabled	tinyint	NOT NULL
	,GroupID	int	NOT NULL
	,RuleName	nvarchar(200)	NOT NULL
	,RuleOrder	smallint	NOT NULL
	,SeverityID	tinyint	NULL
	,SeverityIDCO	char(2)	NULL
	,TicketOwnerID	int	NULL
	,TicketPriorityID	int	NULL
	,TicketRuleID	int	NOT NULL
	,UseAssetOwner	tinyint	NULL
	,FO_TicketRuleID	int	NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'TicketRule_Recovery', null
	RETURN(1)
	END

IF OBJECT_ID('Users_Recovery') IS NOT NULL DROP TABLE dbo.Users_Recovery
IF @IsPrimaryExport = 0
CREATE TABLE dbo.Users_Recovery(
	Domain	nvarchar(255)	NOT NULL
	,Email	nvarchar(255)	NULL
	,LastLogin	datetime	NULL
	,LastLoginFailure	datetime	NULL
	,Login	nvarchar(50)	NOT NULL
	,PrincipalID	int	NOT NULL
	,SID	varchar(50)	NOT NULL
	,FO_MergeCode	CHAR(1)	NULL
	)	
-- standard SQL statement error handling
SELECT	@SaveErrNbr = @@ERROR, 	@SaveRowCnt = @@ROWCOUNT
IF @SaveErrNbr <> 0	
	BEGIN
	IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION
	EXEC iss_error @SaveErrNbr, null, @ProcName, null, null, @FirstError OUTPUT
	EXEC iss_error 55000, 4, @ProcName, @FirstError, 'Users_Recovery', null
	RETURN(1)
	END

RETURN (0)
GO
